@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -38,9 +38,7 @@ class CfnSkill(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        authentication_configuration: typing.Union[
-            "AuthenticationConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        authentication_configuration: typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
         skill_package: typing.Union["SkillPackageProperty", _IResolvable_9ceae33e],
         vendor_id: str,
     ) -> None:
@@ -106,9 +104,7 @@ class CfnSkill(
     @authentication_configuration.setter
     def authentication_configuration(
         self,
-        value: typing.Union[
-            "AuthenticationConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        value: typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "authenticationConfiguration", value)
 
@@ -263,9 +259,7 @@ class CfnSkill(
             *,
             s3_bucket: str,
             s3_key: str,
-            overrides: typing.Optional[
-                typing.Union["CfnSkill.OverridesProperty", _IResolvable_9ceae33e]
-            ] = None,
+            overrides: typing.Optional[typing.Union["CfnSkill.OverridesProperty", _IResolvable_9ceae33e]] = None,
             s3_bucket_role: typing.Optional[str] = None,
             s3_object_version: typing.Optional[str] = None,
         ) -> None:
@@ -311,9 +305,7 @@ class CfnSkill(
         @builtins.property
         def overrides(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnSkill.OverridesProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnSkill.OverridesProperty", _IResolvable_9ceae33e]]:
             """``CfnSkill.SkillPackageProperty.Overrides``.
 
             see
@@ -364,12 +356,8 @@ class CfnSkillProps:
     def __init__(
         self,
         *,
-        authentication_configuration: typing.Union[
-            "CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e
-        ],
-        skill_package: typing.Union[
-            "CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e
-        ],
+        authentication_configuration: typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
+        skill_package: typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e],
         vendor_id: str,
     ) -> None:
         """Properties for defining a ``Alexa::ASK::Skill``.
@@ -390,9 +378,7 @@ class CfnSkillProps:
     @builtins.property
     def authentication_configuration(
         self,
-    ) -> typing.Union[
-        "CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e]:
         """``Alexa::ASK::Skill.AuthenticationConfiguration``.
 
         see
