@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -42,12 +42,7 @@ class CfnAnalyzer(
         *,
         type: str,
         analyzer_name: typing.Optional[str] = None,
-        archive_rules: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        archive_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::AccessAnalyzer::Analyzer``.
@@ -150,12 +145,7 @@ class CfnAnalyzer(
     @jsii.member(jsii_name="archiveRules")
     def archive_rules(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::AccessAnalyzer::Analyzer.ArchiveRules``.
 
         see
@@ -166,12 +156,7 @@ class CfnAnalyzer(
     @archive_rules.setter
     def archive_rules(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ArchiveRuleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "archiveRules", value)
 
@@ -184,12 +169,7 @@ class CfnAnalyzer(
         def __init__(
             self,
             *,
-            filter: typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnAnalyzer.FilterProperty", _IResolvable_9ceae33e]
-                ],
-            ],
+            filter: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAnalyzer.FilterProperty", _IResolvable_9ceae33e]]],
             rule_name: str,
         ) -> None:
             """
@@ -207,12 +187,7 @@ class CfnAnalyzer(
         @builtins.property
         def filter(
             self,
-        ) -> typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnAnalyzer.FilterProperty", _IResolvable_9ceae33e]
-            ],
-        ]:
+        ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAnalyzer.FilterProperty", _IResolvable_9ceae33e]]]:
             """``CfnAnalyzer.ArchiveRuleProperty.Filter``.
 
             see
@@ -356,16 +331,7 @@ class CfnAnalyzerProps:
         *,
         type: str,
         analyzer_name: typing.Optional[str] = None,
-        archive_rules: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnAnalyzer.ArchiveRuleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        archive_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAnalyzer.ArchiveRuleProperty", _IResolvable_9ceae33e]]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::AccessAnalyzer::Analyzer``.
@@ -409,14 +375,7 @@ class CfnAnalyzerProps:
     @builtins.property
     def archive_rules(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnAnalyzer.ArchiveRuleProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAnalyzer.ArchiveRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::AccessAnalyzer::Analyzer.ArchiveRules``.
 
         see
