@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
     CfnTag as _CfnTag_b4661f1a,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -43,9 +43,7 @@ class CfnDataCatalog(
         name: str,
         type: str,
         description: typing.Optional[str] = None,
-        parameters: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ] = None,
+        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
         tags: typing.Optional["TagsProperty"] = None,
     ) -> None:
         """Create a new ``AWS::Athena::DataCatalog``.
@@ -166,9 +164,7 @@ class CfnDataCatalog(
     @parameters.setter
     def parameters(
         self,
-        value: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]],
     ) -> None:
         jsii.set(self, "parameters", value)
 
@@ -230,9 +226,7 @@ class CfnDataCatalogProps:
         name: str,
         type: str,
         description: typing.Optional[str] = None,
-        parameters: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ] = None,
+        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
         tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::DataCatalog``.
@@ -564,22 +558,11 @@ class CfnWorkGroup(
         *,
         name: str,
         description: typing.Optional[str] = None,
-        recursive_delete_option: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        recursive_delete_option: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ] = None,
-        work_group_configuration: typing.Optional[
-            typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]
-        ] = None,
-        work_group_configuration_updates: typing.Optional[
-            typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]
-        ] = None,
+        tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
+        work_group_configuration: typing.Optional[typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::Athena::WorkGroup``.
 
@@ -719,9 +702,7 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfiguration")
     def work_group_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
         see
@@ -732,9 +713,7 @@ class CfnWorkGroup(
     @work_group_configuration.setter
     def work_group_configuration(
         self,
-        value: typing.Optional[
-            typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "workGroupConfiguration", value)
 
@@ -742,9 +721,7 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfigurationUpdates")
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[
-        typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
         see
@@ -755,9 +732,7 @@ class CfnWorkGroup(
     @work_group_configuration_updates.setter
     def work_group_configuration_updates(
         self,
-        value: typing.Optional[
-            typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "workGroupConfigurationUpdates", value)
 
@@ -824,12 +799,7 @@ class CfnWorkGroup(
         def __init__(
             self,
             *,
-            encryption_configuration: typing.Optional[
-                typing.Union[
-                    "CfnWorkGroup.EncryptionConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            encryption_configuration: typing.Optional[typing.Union["CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e]] = None,
             output_location: typing.Optional[str] = None,
         ) -> None:
             """
@@ -848,11 +818,7 @@ class CfnWorkGroup(
         @builtins.property
         def encryption_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
 
             see
@@ -894,19 +860,10 @@ class CfnWorkGroup(
         def __init__(
             self,
             *,
-            encryption_configuration: typing.Optional[
-                typing.Union[
-                    "CfnWorkGroup.EncryptionConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            encryption_configuration: typing.Optional[typing.Union["CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e]] = None,
             output_location: typing.Optional[str] = None,
-            remove_encryption_configuration: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            remove_output_location: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            remove_encryption_configuration: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            remove_output_location: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
@@ -923,20 +880,14 @@ class CfnWorkGroup(
             if output_location is not None:
                 self._values["output_location"] = output_location
             if remove_encryption_configuration is not None:
-                self._values[
-                    "remove_encryption_configuration"
-                ] = remove_encryption_configuration
+                self._values["remove_encryption_configuration"] = remove_encryption_configuration
             if remove_output_location is not None:
                 self._values["remove_output_location"] = remove_output_location
 
         @builtins.property
         def encryption_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
 
             see
@@ -1002,20 +953,10 @@ class CfnWorkGroup(
             self,
             *,
             bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
-            enforce_work_group_configuration: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            publish_cloud_watch_metrics_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            requester_pays_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            result_configuration: typing.Optional[
-                typing.Union[
-                    "CfnWorkGroup.ResultConfigurationProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            enforce_work_group_configuration: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            requester_pays_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            result_configuration: typing.Optional[typing.Union["CfnWorkGroup.ResultConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
@@ -1029,17 +970,11 @@ class CfnWorkGroup(
             """
             self._values = {}
             if bytes_scanned_cutoff_per_query is not None:
-                self._values[
-                    "bytes_scanned_cutoff_per_query"
-                ] = bytes_scanned_cutoff_per_query
+                self._values["bytes_scanned_cutoff_per_query"] = bytes_scanned_cutoff_per_query
             if enforce_work_group_configuration is not None:
-                self._values[
-                    "enforce_work_group_configuration"
-                ] = enforce_work_group_configuration
+                self._values["enforce_work_group_configuration"] = enforce_work_group_configuration
             if publish_cloud_watch_metrics_enabled is not None:
-                self._values[
-                    "publish_cloud_watch_metrics_enabled"
-                ] = publish_cloud_watch_metrics_enabled
+                self._values["publish_cloud_watch_metrics_enabled"] = publish_cloud_watch_metrics_enabled
             if requester_pays_enabled is not None:
                 self._values["requester_pays_enabled"] = requester_pays_enabled
             if result_configuration is not None:
@@ -1090,11 +1025,7 @@ class CfnWorkGroup(
         @builtins.property
         def result_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnWorkGroup.ResultConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnWorkGroup.ResultConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
             see
@@ -1130,24 +1061,11 @@ class CfnWorkGroup(
             self,
             *,
             bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
-            enforce_work_group_configuration: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            publish_cloud_watch_metrics_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            remove_bytes_scanned_cutoff_per_query: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            requester_pays_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            result_configuration_updates: typing.Optional[
-                typing.Union[
-                    "CfnWorkGroup.ResultConfigurationUpdatesProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            enforce_work_group_configuration: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            requester_pays_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            result_configuration_updates: typing.Optional[typing.Union["CfnWorkGroup.ResultConfigurationUpdatesProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
@@ -1162,27 +1080,17 @@ class CfnWorkGroup(
             """
             self._values = {}
             if bytes_scanned_cutoff_per_query is not None:
-                self._values[
-                    "bytes_scanned_cutoff_per_query"
-                ] = bytes_scanned_cutoff_per_query
+                self._values["bytes_scanned_cutoff_per_query"] = bytes_scanned_cutoff_per_query
             if enforce_work_group_configuration is not None:
-                self._values[
-                    "enforce_work_group_configuration"
-                ] = enforce_work_group_configuration
+                self._values["enforce_work_group_configuration"] = enforce_work_group_configuration
             if publish_cloud_watch_metrics_enabled is not None:
-                self._values[
-                    "publish_cloud_watch_metrics_enabled"
-                ] = publish_cloud_watch_metrics_enabled
+                self._values["publish_cloud_watch_metrics_enabled"] = publish_cloud_watch_metrics_enabled
             if remove_bytes_scanned_cutoff_per_query is not None:
-                self._values[
-                    "remove_bytes_scanned_cutoff_per_query"
-                ] = remove_bytes_scanned_cutoff_per_query
+                self._values["remove_bytes_scanned_cutoff_per_query"] = remove_bytes_scanned_cutoff_per_query
             if requester_pays_enabled is not None:
                 self._values["requester_pays_enabled"] = requester_pays_enabled
             if result_configuration_updates is not None:
-                self._values[
-                    "result_configuration_updates"
-                ] = result_configuration_updates
+                self._values["result_configuration_updates"] = result_configuration_updates
 
         @builtins.property
         def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
@@ -1240,11 +1148,7 @@ class CfnWorkGroup(
         @builtins.property
         def result_configuration_updates(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnWorkGroup.ResultConfigurationUpdatesProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnWorkGroup.ResultConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
             see
@@ -1283,27 +1187,11 @@ class CfnWorkGroupProps:
         *,
         name: str,
         description: typing.Optional[str] = None,
-        recursive_delete_option: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        recursive_delete_option: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ] = None,
-        work_group_configuration: typing.Optional[
-            typing.Union[
-                "CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
-        work_group_configuration_updates: typing.Optional[
-            typing.Union[
-                "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ] = None,
+        tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
+        work_group_configuration: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::WorkGroup``.
 
@@ -1332,9 +1220,7 @@ class CfnWorkGroupProps:
         if work_group_configuration is not None:
             self._values["work_group_configuration"] = work_group_configuration
         if work_group_configuration_updates is not None:
-            self._values[
-                "work_group_configuration_updates"
-            ] = work_group_configuration_updates
+            self._values["work_group_configuration_updates"] = work_group_configuration_updates
 
     @builtins.property
     def name(self) -> str:
@@ -1377,12 +1263,7 @@ class CfnWorkGroupProps:
     @builtins.property
     def tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
         """``AWS::Athena::WorkGroup.Tags``.
 
         see
@@ -1393,11 +1274,7 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
         see
@@ -1408,11 +1285,7 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
         see
