@@ -12,16 +12,16 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
+    CfnTag as _CfnTag_b4661f1a,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
+    CustomResource as _CustomResource_ed3258f5,
+    Duration as _Duration_5170c158,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
-    CfnTag as _CfnTag_b4661f1a,
-    TagManager as _TagManager_2508893f,
-    CustomResource as _CustomResource_ed3258f5,
-    RemovalPolicy as _RemovalPolicy_5986e9f3,
     NestedStack as _NestedStack_e205561c,
-    Duration as _Duration_5170c158,
+    RemovalPolicy as _RemovalPolicy_5986e9f3,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_lambda import IFunction as _IFunction_1c1de0bc
 from ..aws_sns import ITopic as _ITopic_ef0ebe0e
@@ -407,9 +407,7 @@ class CfnStack(
         *,
         template_url: str,
         notification_arns: typing.Optional[typing.List[str]] = None,
-        parameters: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ] = None,
+        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         timeout_in_minutes: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -517,9 +515,7 @@ class CfnStack(
     @parameters.setter
     def parameters(
         self,
-        value: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]],
     ) -> None:
         jsii.set(self, "parameters", value)
 
@@ -555,9 +551,7 @@ class CfnStackProps:
         *,
         template_url: str,
         notification_arns: typing.Optional[typing.List[str]] = None,
-        parameters: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ] = None,
+        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         timeout_in_minutes: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -870,7 +864,9 @@ class CfnWaitConditionProps:
         )
 
 
-@jsii.enum(jsii_type="monocdk-experiment.aws_cloudformation.CloudFormationCapabilities")
+@jsii.enum(
+    jsii_type="monocdk-experiment.aws_cloudformation.CloudFormationCapabilities"
+)
 class CloudFormationCapabilities(enum.Enum):
     """Capabilities that affect whether CloudFormation is allowed to change IAM resources.
 
