@@ -12,25 +12,24 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_events import (
-    Rule as _Rule_c38e0b39,
-    OnEventOptions as _OnEventOptions_926fbcf9,
     EventPattern as _EventPattern_8aa7b781,
     IRuleTarget as _IRuleTarget_41800a77,
+    OnEventOptions as _OnEventOptions_926fbcf9,
+    Rule as _Rule_c38e0b39,
 )
 from ..aws_kms import IKey as _IKey_3336c79d
 from ..aws_lambda import IFunction as _IFunction_1c1de0bc
 from ..aws_logs import (
-    ILogGroup as _ILogGroup_6b54c8e1,
-    RetentionDays as _RetentionDays_bdc7ad1f,
+    ILogGroup as _ILogGroup_6b54c8e1, RetentionDays as _RetentionDays_bdc7ad1f
 )
 from ..aws_s3 import IBucket as _IBucket_25bad983
 from ..aws_sns import ITopic as _ITopic_ef0ebe0e
@@ -124,23 +123,10 @@ class CfnTrail(
         s3_bucket_name: str,
         cloud_watch_logs_log_group_arn: typing.Optional[str] = None,
         cloud_watch_logs_role_arn: typing.Optional[str] = None,
-        enable_log_file_validation: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        event_selectors: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["EventSelectorProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
-        include_global_service_events: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        is_multi_region_trail: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        enable_log_file_validation: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        event_selectors: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EventSelectorProperty", _IResolvable_9ceae33e]]]] = None,
+        include_global_service_events: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        is_multi_region_trail: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         kms_key_id: typing.Optional[str] = None,
         s3_key_prefix: typing.Optional[str] = None,
         sns_topic_name: typing.Optional[str] = None,
@@ -320,12 +306,7 @@ class CfnTrail(
     @jsii.member(jsii_name="eventSelectors")
     def event_selectors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["EventSelectorProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EventSelectorProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CloudTrail::Trail.EventSelectors``.
 
         see
@@ -336,14 +317,7 @@ class CfnTrail(
     @event_selectors.setter
     def event_selectors(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["EventSelectorProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EventSelectorProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "eventSelectors", value)
 
@@ -503,19 +477,8 @@ class CfnTrail(
         def __init__(
             self,
             *,
-            data_resources: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnTrail.DataResourceProperty", _IResolvable_9ceae33e
-                        ]
-                    ],
-                ]
-            ] = None,
-            include_management_events: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            data_resources: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTrail.DataResourceProperty", _IResolvable_9ceae33e]]]] = None,
+            include_management_events: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             read_write_type: typing.Optional[str] = None,
         ) -> None:
             """
@@ -537,14 +500,7 @@ class CfnTrail(
         @builtins.property
         def data_resources(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnTrail.DataResourceProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTrail.DataResourceProperty", _IResolvable_9ceae33e]]]]:
             """``CfnTrail.EventSelectorProperty.DataResources``.
 
             see
@@ -611,25 +567,10 @@ class CfnTrailProps:
         s3_bucket_name: str,
         cloud_watch_logs_log_group_arn: typing.Optional[str] = None,
         cloud_watch_logs_role_arn: typing.Optional[str] = None,
-        enable_log_file_validation: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        event_selectors: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnTrail.EventSelectorProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
-        include_global_service_events: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        is_multi_region_trail: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        enable_log_file_validation: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        event_selectors: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTrail.EventSelectorProperty", _IResolvable_9ceae33e]]]] = None,
+        include_global_service_events: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        is_multi_region_trail: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         kms_key_id: typing.Optional[str] = None,
         s3_key_prefix: typing.Optional[str] = None,
         sns_topic_name: typing.Optional[str] = None,
@@ -660,9 +601,7 @@ class CfnTrailProps:
             "s3_bucket_name": s3_bucket_name,
         }
         if cloud_watch_logs_log_group_arn is not None:
-            self._values[
-                "cloud_watch_logs_log_group_arn"
-            ] = cloud_watch_logs_log_group_arn
+            self._values["cloud_watch_logs_log_group_arn"] = cloud_watch_logs_log_group_arn
         if cloud_watch_logs_role_arn is not None:
             self._values["cloud_watch_logs_role_arn"] = cloud_watch_logs_role_arn
         if enable_log_file_validation is not None:
@@ -670,9 +609,7 @@ class CfnTrailProps:
         if event_selectors is not None:
             self._values["event_selectors"] = event_selectors
         if include_global_service_events is not None:
-            self._values[
-                "include_global_service_events"
-            ] = include_global_service_events
+            self._values["include_global_service_events"] = include_global_service_events
         if is_multi_region_trail is not None:
             self._values["is_multi_region_trail"] = is_multi_region_trail
         if kms_key_id is not None:
@@ -736,14 +673,7 @@ class CfnTrailProps:
     @builtins.property
     def event_selectors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnTrail.EventSelectorProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTrail.EventSelectorProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CloudTrail::Trail.EventSelectors``.
 
         see
@@ -1093,11 +1023,7 @@ class Trail(
             read_write_type=read_write_type,
         )
 
-        return jsii.invoke(
-            self,
-            "addEventSelector",
-            [data_resource_type, data_resource_values, options],
-        )
+        return jsii.invoke(self, "addEventSelector", [data_resource_type, data_resource_values, options])
 
     @jsii.member(jsii_name="addLambdaEventSelector")
     def add_lambda_event_selector(
@@ -1358,9 +1284,7 @@ class TrailProps:
         if encryption_key is not None:
             self._values["encryption_key"] = encryption_key
         if include_global_service_events is not None:
-            self._values[
-                "include_global_service_events"
-            ] = include_global_service_events
+            self._values["include_global_service_events"] = include_global_service_events
         if is_multi_region_trail is not None:
             self._values["is_multi_region_trail"] = is_multi_region_trail
         if kms_key is not None:
