@@ -12,7 +12,7 @@ from .._jsii import *
 
 from .. import Construct as _Construct_f50a3f53
 from ..aws_applicationautoscaling import (
-    StepScalingAction as _StepScalingAction_e6a08ac3,
+    StepScalingAction as _StepScalingAction_e6a08ac3
 )
 from ..aws_autoscaling import StepScalingAction as _StepScalingAction_24342ebd
 from ..aws_cloudwatch import (
