@@ -12,20 +12,20 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     IResource as _IResource_72f7ee7e,
     Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_events import (
-    Rule as _Rule_c38e0b39,
-    OnEventOptions as _OnEventOptions_926fbcf9,
     EventPattern as _EventPattern_8aa7b781,
     IRuleTarget as _IRuleTarget_41800a77,
+    OnEventOptions as _OnEventOptions_926fbcf9,
+    Rule as _Rule_c38e0b39,
 )
 from ..aws_iam import Grant as _Grant_96af6d2d, IGrantable as _IGrantable_0fcfc53a
 
@@ -50,19 +50,10 @@ class CfnRepository(
         id: str,
         *,
         repository_name: str,
-        code: typing.Optional[
-            typing.Union["CodeProperty", _IResolvable_9ceae33e]
-        ] = None,
+        code: typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]] = None,
         repository_description: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        triggers: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["RepositoryTriggerProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        triggers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryTriggerProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::CodeCommit::Repository``.
 
@@ -212,14 +203,7 @@ class CfnRepository(
     @jsii.member(jsii_name="triggers")
     def triggers(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["RepositoryTriggerProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryTriggerProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CodeCommit::Repository.Triggers``.
 
         see
@@ -230,14 +214,7 @@ class CfnRepository(
     @triggers.setter
     def triggers(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["RepositoryTriggerProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryTriggerProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "triggers", value)
 
@@ -248,7 +225,9 @@ class CfnRepository(
     )
     class CodeProperty:
         def __init__(
-            self, *, s3: typing.Union["CfnRepository.S3Property", _IResolvable_9ceae33e]
+            self,
+            *,
+            s3: typing.Union["CfnRepository.S3Property", _IResolvable_9ceae33e],
         ) -> None:
             """
             :param s3: ``CfnRepository.CodeProperty.S3``.
@@ -460,21 +439,10 @@ class CfnRepositoryProps:
         self,
         *,
         repository_name: str,
-        code: typing.Optional[
-            typing.Union["CfnRepository.CodeProperty", _IResolvable_9ceae33e]
-        ] = None,
+        code: typing.Optional[typing.Union["CfnRepository.CodeProperty", _IResolvable_9ceae33e]] = None,
         repository_description: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        triggers: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnRepository.RepositoryTriggerProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        triggers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnRepository.RepositoryTriggerProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeCommit::Repository``.
 
@@ -511,9 +479,7 @@ class CfnRepositoryProps:
     @builtins.property
     def code(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnRepository.CodeProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnRepository.CodeProperty", _IResolvable_9ceae33e]]:
         """``AWS::CodeCommit::Repository.Code``.
 
         see
@@ -542,16 +508,7 @@ class CfnRepositoryProps:
     @builtins.property
     def triggers(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnRepository.RepositoryTriggerProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnRepository.RepositoryTriggerProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CodeCommit::Repository.Triggers``.
 
         see
