@@ -13,10 +13,10 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -49,9 +49,7 @@ class CfnCluster(
         parameter_group_name: typing.Optional[str] = None,
         preferred_maintenance_window: typing.Optional[str] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
-        sse_specification: typing.Optional[
-            typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        sse_specification: typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
         subnet_group_name: typing.Optional[str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -294,9 +292,7 @@ class CfnCluster(
     @jsii.member(jsii_name="sseSpecification")
     def sse_specification(
         self,
-    ) -> typing.Optional[
-        typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
@@ -307,9 +303,7 @@ class CfnCluster(
     @sse_specification.setter
     def sse_specification(
         self,
-        value: typing.Optional[
-            typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "sseSpecification", value)
 
@@ -336,9 +330,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            sse_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            sse_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
@@ -406,9 +398,7 @@ class CfnClusterProps:
         parameter_group_name: typing.Optional[str] = None,
         preferred_maintenance_window: typing.Optional[str] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
-        sse_specification: typing.Optional[
-            typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        sse_specification: typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
         subnet_group_name: typing.Optional[str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -550,9 +540,7 @@ class CfnClusterProps:
     @builtins.property
     def sse_specification(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
