@@ -12,11 +12,11 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
+    CfnTag as _CfnTag_b4661f1a,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    CfnTag as _CfnTag_b4661f1a,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -41,9 +41,7 @@ class CfnLifecyclePolicy(
         *,
         description: typing.Optional[str] = None,
         execution_role_arn: typing.Optional[str] = None,
-        policy_details: typing.Optional[
-            typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        policy_details: typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
         state: typing.Optional[str] = None,
     ) -> None:
         """Create a new ``AWS::DLM::LifecyclePolicy``.
@@ -147,9 +145,7 @@ class CfnLifecyclePolicy(
     @policy_details.setter
     def policy_details(
         self,
-        value: typing.Optional[
-            typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "policyDetails", value)
 
@@ -318,15 +314,8 @@ class CfnLifecyclePolicy(
             encrypted: typing.Union[bool, _IResolvable_9ceae33e],
             target_region: str,
             cmk_arn: typing.Optional[str] = None,
-            copy_tags: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            retain_rule: typing.Optional[
-                typing.Union[
-                    "CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            copy_tags: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            retain_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param encrypted: ``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.Encrypted``.
@@ -390,12 +379,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def retain_rule(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.RetainRule``.
 
             see
@@ -508,9 +492,7 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            exclude_boot_volume: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            exclude_boot_volume: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param exclude_boot_volume: ``CfnLifecyclePolicy.ParametersProperty.ExcludeBootVolume``.
@@ -560,23 +542,9 @@ class CfnLifecyclePolicy(
             self,
             *,
             resource_types: typing.List[str],
-            schedules: typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnLifecyclePolicy.ScheduleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ],
-            target_tags: typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ],
-            parameters: typing.Optional[
-                typing.Union[
-                    "CfnLifecyclePolicy.ParametersProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            schedules: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.ScheduleProperty", _IResolvable_9ceae33e]]],
+            target_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
+            parameters: typing.Optional[typing.Union["CfnLifecyclePolicy.ParametersProperty", _IResolvable_9ceae33e]] = None,
             policy_type: typing.Optional[str] = None,
         ) -> None:
             """
@@ -611,14 +579,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def schedules(
             self,
-        ) -> typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnLifecyclePolicy.ScheduleProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]:
+        ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.ScheduleProperty", _IResolvable_9ceae33e]]]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.Schedules``.
 
             see
@@ -629,10 +590,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def target_tags(
             self,
-        ) -> typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ]:
+        ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.TargetTags``.
 
             see
@@ -643,9 +601,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def parameters(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnLifecyclePolicy.ParametersProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.ParametersProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.Parameters``.
 
             see
@@ -762,48 +718,14 @@ class CfnLifecyclePolicy(
         def __init__(
             self,
             *,
-            copy_tags: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            create_rule: typing.Optional[
-                typing.Union[
-                    "CfnLifecyclePolicy.CreateRuleProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            cross_region_copy_rules: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnLifecyclePolicy.CrossRegionCopyRuleProperty",
-                            _IResolvable_9ceae33e,
-                        ]
-                    ],
-                ]
-            ] = None,
-            fast_restore_rule: typing.Optional[
-                typing.Union[
-                    "CfnLifecyclePolicy.FastRestoreRuleProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            copy_tags: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            create_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.CreateRuleProperty", _IResolvable_9ceae33e]] = None,
+            cross_region_copy_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRuleProperty", _IResolvable_9ceae33e]]]] = None,
+            fast_restore_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.FastRestoreRuleProperty", _IResolvable_9ceae33e]] = None,
             name: typing.Optional[str] = None,
-            retain_rule: typing.Optional[
-                typing.Union[
-                    "CfnLifecyclePolicy.RetainRuleProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            tags_to_add: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-                ]
-            ] = None,
-            variable_tags: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-                ]
-            ] = None,
+            retain_rule: typing.Optional[typing.Union["CfnLifecyclePolicy.RetainRuleProperty", _IResolvable_9ceae33e]] = None,
+            tags_to_add: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
+            variable_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
         ) -> None:
             """
             :param copy_tags: ``CfnLifecyclePolicy.ScheduleProperty.CopyTags``.
@@ -850,9 +772,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def create_rule(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnLifecyclePolicy.CreateRuleProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.CreateRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.CreateRule``.
 
             see
@@ -863,17 +783,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def cross_region_copy_rules(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnLifecyclePolicy.CrossRegionCopyRuleProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRuleProperty", _IResolvable_9ceae33e]]]]:
             """``CfnLifecyclePolicy.ScheduleProperty.CrossRegionCopyRules``.
 
             see
@@ -884,11 +794,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def fast_restore_rule(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnLifecyclePolicy.FastRestoreRuleProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.FastRestoreRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.FastRestoreRule``.
 
             see
@@ -908,9 +814,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def retain_rule(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnLifecyclePolicy.RetainRuleProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.RetainRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.RetainRule``.
 
             see
@@ -921,12 +825,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def tags_to_add(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
             """``CfnLifecyclePolicy.ScheduleProperty.TagsToAdd``.
 
             see
@@ -937,12 +836,7 @@ class CfnLifecyclePolicy(
         @builtins.property
         def variable_tags(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
             """``CfnLifecyclePolicy.ScheduleProperty.VariableTags``.
 
             see
@@ -978,11 +872,7 @@ class CfnLifecyclePolicyProps:
         *,
         description: typing.Optional[str] = None,
         execution_role_arn: typing.Optional[str] = None,
-        policy_details: typing.Optional[
-            typing.Union[
-                "CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        policy_details: typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
         state: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DLM::LifecyclePolicy``.
@@ -1026,9 +916,7 @@ class CfnLifecyclePolicyProps:
     @builtins.property
     def policy_details(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]]:
         """``AWS::DLM::LifecyclePolicy.PolicyDetails``.
 
         see
