@@ -11,24 +11,24 @@ import publication
 from .._jsii import *
 
 from .. import (
-    Resource as _Resource_884d0774,
-    Construct as _Construct_f50a3f53,
     CfnResource as _CfnResource_7760e8e4,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
-    TagManager as _TagManager_2508893f,
-    Size as _Size_b4ccfc18,
-    RemovalPolicy as _RemovalPolicy_5986e9f3,
+    Construct as _Construct_f50a3f53,
     IDependable as _IDependable_4fc803f7,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     IResource as _IResource_72f7ee7e,
+    RemovalPolicy as _RemovalPolicy_5986e9f3,
+    Resource as _Resource_884d0774,
+    Size as _Size_b4ccfc18,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_ec2 import (
-    IVpc as _IVpc_3795853f,
-    ISecurityGroup as _ISecurityGroup_d72ab8e8,
-    SubnetSelection as _SubnetSelection_36a13cd6,
     Connections as _Connections_231f38b5,
     IConnectable as _IConnectable_a587039f,
+    ISecurityGroup as _ISecurityGroup_d72ab8e8,
+    IVpc as _IVpc_3795853f,
+    SubnetSelection as _SubnetSelection_36a13cd6,
 )
 from ..aws_kms import IKey as _IKey_3336c79d
 
@@ -36,7 +36,11 @@ from ..aws_kms import IKey as _IKey_3336c79d
 @jsii.data_type(
     jsii_type="monocdk-experiment.aws_efs.AccessPointOptions",
     jsii_struct_bases=[],
-    name_mapping={"create_acl": "createAcl", "path": "path", "posix_user": "posixUser"},
+    name_mapping={
+        "create_acl": "createAcl",
+        "path": "path",
+        "posix_user": "posixUser",
+    },
 )
 class AccessPointOptions:
     def __init__(
@@ -295,7 +299,9 @@ class Acl:
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return "Acl(%s)" % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
+        return "Acl(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
@@ -318,21 +324,10 @@ class CfnAccessPoint(
         id: str,
         *,
         file_system_id: str,
-        access_point_tags: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["AccessPointTagProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        access_point_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["AccessPointTagProperty", _IResolvable_9ceae33e]]]] = None,
         client_token: typing.Optional[str] = None,
-        posix_user: typing.Optional[
-            typing.Union["PosixUserProperty", _IResolvable_9ceae33e]
-        ] = None,
-        root_directory: typing.Optional[
-            typing.Union["RootDirectoryProperty", _IResolvable_9ceae33e]
-        ] = None,
+        posix_user: typing.Optional[typing.Union["PosixUserProperty", _IResolvable_9ceae33e]] = None,
+        root_directory: typing.Optional[typing.Union["RootDirectoryProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::EFS::AccessPoint``.
 
@@ -421,12 +416,7 @@ class CfnAccessPoint(
     @jsii.member(jsii_name="accessPointTags")
     def access_point_tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["AccessPointTagProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["AccessPointTagProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::EFS::AccessPoint.AccessPointTags``.
 
         see
@@ -437,14 +427,7 @@ class CfnAccessPoint(
     @access_point_tags.setter
     def access_point_tags(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["AccessPointTagProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["AccessPointTagProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "accessPointTags", value)
 
@@ -477,9 +460,7 @@ class CfnAccessPoint(
     @posix_user.setter
     def posix_user(
         self,
-        value: typing.Optional[
-            typing.Union["PosixUserProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["PosixUserProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "posixUser", value)
 
@@ -498,9 +479,7 @@ class CfnAccessPoint(
     @root_directory.setter
     def root_directory(
         self,
-        value: typing.Optional[
-            typing.Union["RootDirectoryProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["RootDirectoryProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "rootDirectory", value)
 
@@ -696,11 +675,7 @@ class CfnAccessPoint(
         def __init__(
             self,
             *,
-            creation_info: typing.Optional[
-                typing.Union[
-                    "CfnAccessPoint.CreationInfoProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            creation_info: typing.Optional[typing.Union["CfnAccessPoint.CreationInfoProperty", _IResolvable_9ceae33e]] = None,
             path: typing.Optional[str] = None,
         ) -> None:
             """
@@ -719,9 +694,7 @@ class CfnAccessPoint(
         @builtins.property
         def creation_info(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnAccessPoint.CreationInfoProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnAccessPoint.CreationInfoProperty", _IResolvable_9ceae33e]]:
             """``CfnAccessPoint.RootDirectoryProperty.CreationInfo``.
 
             see
@@ -766,23 +739,10 @@ class CfnAccessPointProps:
         self,
         *,
         file_system_id: str,
-        access_point_tags: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnAccessPoint.AccessPointTagProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        access_point_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAccessPoint.AccessPointTagProperty", _IResolvable_9ceae33e]]]] = None,
         client_token: typing.Optional[str] = None,
-        posix_user: typing.Optional[
-            typing.Union["CfnAccessPoint.PosixUserProperty", _IResolvable_9ceae33e]
-        ] = None,
-        root_directory: typing.Optional[
-            typing.Union["CfnAccessPoint.RootDirectoryProperty", _IResolvable_9ceae33e]
-        ] = None,
+        posix_user: typing.Optional[typing.Union["CfnAccessPoint.PosixUserProperty", _IResolvable_9ceae33e]] = None,
+        root_directory: typing.Optional[typing.Union["CfnAccessPoint.RootDirectoryProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EFS::AccessPoint``.
 
@@ -819,16 +779,7 @@ class CfnAccessPointProps:
     @builtins.property
     def access_point_tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnAccessPoint.AccessPointTagProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnAccessPoint.AccessPointTagProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::EFS::AccessPoint.AccessPointTags``.
 
         see
@@ -848,9 +799,7 @@ class CfnAccessPointProps:
     @builtins.property
     def posix_user(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnAccessPoint.PosixUserProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnAccessPoint.PosixUserProperty", _IResolvable_9ceae33e]]:
         """``AWS::EFS::AccessPoint.PosixUser``.
 
         see
@@ -861,9 +810,7 @@ class CfnAccessPointProps:
     @builtins.property
     def root_directory(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnAccessPoint.RootDirectoryProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnAccessPoint.RootDirectoryProperty", _IResolvable_9ceae33e]]:
         """``AWS::EFS::AccessPoint.RootDirectory``.
 
         see
@@ -902,23 +849,12 @@ class CfnFileSystem(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        backup_policy: typing.Optional[
-            typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
+        backup_policy: typing.Optional[typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]] = None,
         encrypted: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         file_system_policy: typing.Any = None,
-        file_system_tags: typing.Optional[
-            typing.List["ElasticFileSystemTagProperty"]
-        ] = None,
+        file_system_tags: typing.Optional[typing.List["ElasticFileSystemTagProperty"]] = None,
         kms_key_id: typing.Optional[str] = None,
-        lifecycle_policies: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        lifecycle_policies: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]]]] = None,
         performance_mode: typing.Optional[str] = None,
         provisioned_throughput_in_mibps: typing.Optional[jsii.Number] = None,
         throughput_mode: typing.Optional[str] = None,
@@ -1039,9 +975,7 @@ class CfnFileSystem(
     @backup_policy.setter
     def backup_policy(
         self,
-        value: typing.Optional[
-            typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "backupPolicy", value)
 
@@ -1079,12 +1013,7 @@ class CfnFileSystem(
     @jsii.member(jsii_name="lifecyclePolicies")
     def lifecycle_policies(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::EFS::FileSystem.LifecyclePolicies``.
 
         see
@@ -1095,14 +1024,7 @@ class CfnFileSystem(
     @lifecycle_policies.setter
     def lifecycle_policies(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "lifecyclePolicies", value)
 
@@ -1292,25 +1214,12 @@ class CfnFileSystemProps:
     def __init__(
         self,
         *,
-        backup_policy: typing.Optional[
-            typing.Union["CfnFileSystem.BackupPolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
+        backup_policy: typing.Optional[typing.Union["CfnFileSystem.BackupPolicyProperty", _IResolvable_9ceae33e]] = None,
         encrypted: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         file_system_policy: typing.Any = None,
-        file_system_tags: typing.Optional[
-            typing.List["CfnFileSystem.ElasticFileSystemTagProperty"]
-        ] = None,
+        file_system_tags: typing.Optional[typing.List["CfnFileSystem.ElasticFileSystemTagProperty"]] = None,
         kms_key_id: typing.Optional[str] = None,
-        lifecycle_policies: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnFileSystem.LifecyclePolicyProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        lifecycle_policies: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnFileSystem.LifecyclePolicyProperty", _IResolvable_9ceae33e]]]] = None,
         performance_mode: typing.Optional[str] = None,
         provisioned_throughput_in_mibps: typing.Optional[jsii.Number] = None,
         throughput_mode: typing.Optional[str] = None,
@@ -1346,18 +1255,14 @@ class CfnFileSystemProps:
         if performance_mode is not None:
             self._values["performance_mode"] = performance_mode
         if provisioned_throughput_in_mibps is not None:
-            self._values[
-                "provisioned_throughput_in_mibps"
-            ] = provisioned_throughput_in_mibps
+            self._values["provisioned_throughput_in_mibps"] = provisioned_throughput_in_mibps
         if throughput_mode is not None:
             self._values["throughput_mode"] = throughput_mode
 
     @builtins.property
     def backup_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnFileSystem.BackupPolicyProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnFileSystem.BackupPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::EFS::FileSystem.BackupPolicy``.
 
         see
@@ -1406,16 +1311,7 @@ class CfnFileSystemProps:
     @builtins.property
     def lifecycle_policies(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnFileSystem.LifecyclePolicyProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnFileSystem.LifecyclePolicyProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::EFS::FileSystem.LifecyclePolicies``.
 
         see
@@ -1804,9 +1700,7 @@ class FileSystemProps:
         if performance_mode is not None:
             self._values["performance_mode"] = performance_mode
         if provisioned_throughput_per_second is not None:
-            self._values[
-                "provisioned_throughput_per_second"
-            ] = provisioned_throughput_per_second
+            self._values["provisioned_throughput_per_second"] = provisioned_throughput_per_second
         if removal_policy is not None:
             self._values["removal_policy"] = removal_policy
         if security_group is not None:
