@@ -12,21 +12,21 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
-    IInspectable as _IInspectable_051e6ed8,
+    Construct as _Construct_f50a3f53,
     Duration as _Duration_5170c158,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_ec2 import (
+    Connections as _Connections_231f38b5,
     IConnectable as _IConnectable_a587039f,
     ISecurityGroup as _ISecurityGroup_d72ab8e8,
-    Port as _Port_7d870cca,
-    Connections as _Connections_231f38b5,
     IVpc as _IVpc_3795853f,
+    Port as _Port_7d870cca,
     SubnetSelection as _SubnetSelection_36a13cd6,
 )
 
@@ -50,52 +50,18 @@ class CfnLoadBalancer(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        listeners: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ListenersProperty", _IResolvable_9ceae33e]],
-        ],
-        access_logging_policy: typing.Optional[
-            typing.Union["AccessLoggingPolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
-        app_cookie_stickiness_policy: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        listeners: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ListenersProperty", _IResolvable_9ceae33e]]],
+        access_logging_policy: typing.Optional[typing.Union["AccessLoggingPolicyProperty", _IResolvable_9ceae33e]] = None,
+        app_cookie_stickiness_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]] = None,
         availability_zones: typing.Optional[typing.List[str]] = None,
-        connection_draining_policy: typing.Optional[
-            typing.Union["ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
-        connection_settings: typing.Optional[
-            typing.Union["ConnectionSettingsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        connection_draining_policy: typing.Optional[typing.Union["ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]] = None,
+        connection_settings: typing.Optional[typing.Union["ConnectionSettingsProperty", _IResolvable_9ceae33e]] = None,
         cross_zone: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        health_check: typing.Optional[
-            typing.Union["HealthCheckProperty", _IResolvable_9ceae33e]
-        ] = None,
+        health_check: typing.Optional[typing.Union["HealthCheckProperty", _IResolvable_9ceae33e]] = None,
         instances: typing.Optional[typing.List[str]] = None,
-        lb_cookie_stickiness_policy: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        lb_cookie_stickiness_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]] = None,
         load_balancer_name: typing.Optional[str] = None,
-        policies: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["PoliciesProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        policies: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PoliciesProperty", _IResolvable_9ceae33e]]]] = None,
         scheme: typing.Optional[str] = None,
         security_groups: typing.Optional[typing.List[str]] = None,
         subnets: typing.Optional[typing.List[str]] = None,
@@ -233,10 +199,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="listeners")
     def listeners(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["ListenersProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ListenersProperty", _IResolvable_9ceae33e]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.Listeners``.
 
         see
@@ -247,10 +210,7 @@ class CfnLoadBalancer(
     @listeners.setter
     def listeners(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ListenersProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ListenersProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "listeners", value)
 
@@ -258,9 +218,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="accessLoggingPolicy")
     def access_logging_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union["AccessLoggingPolicyProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["AccessLoggingPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.AccessLoggingPolicy``.
 
         see
@@ -271,9 +229,7 @@ class CfnLoadBalancer(
     @access_logging_policy.setter
     def access_logging_policy(
         self,
-        value: typing.Optional[
-            typing.Union["AccessLoggingPolicyProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["AccessLoggingPolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "accessLoggingPolicy", value)
 
@@ -281,14 +237,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="appCookieStickinessPolicy")
     def app_cookie_stickiness_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.AppCookieStickinessPolicy``.
 
         see
@@ -299,16 +248,7 @@ class CfnLoadBalancer(
     @app_cookie_stickiness_policy.setter
     def app_cookie_stickiness_policy(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "appCookieStickinessPolicy", value)
 
@@ -330,9 +270,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="connectionDrainingPolicy")
     def connection_draining_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union["ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.ConnectionDrainingPolicy``.
 
         see
@@ -343,9 +281,7 @@ class CfnLoadBalancer(
     @connection_draining_policy.setter
     def connection_draining_policy(
         self,
-        value: typing.Optional[
-            typing.Union["ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "connectionDrainingPolicy", value)
 
@@ -353,9 +289,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="connectionSettings")
     def connection_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union["ConnectionSettingsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["ConnectionSettingsProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.ConnectionSettings``.
 
         see
@@ -366,9 +300,7 @@ class CfnLoadBalancer(
     @connection_settings.setter
     def connection_settings(
         self,
-        value: typing.Optional[
-            typing.Union["ConnectionSettingsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["ConnectionSettingsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "connectionSettings", value)
 
@@ -403,9 +335,7 @@ class CfnLoadBalancer(
     @health_check.setter
     def health_check(
         self,
-        value: typing.Optional[
-            typing.Union["HealthCheckProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["HealthCheckProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "healthCheck", value)
 
@@ -427,14 +357,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="lbCookieStickinessPolicy")
     def lb_cookie_stickiness_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.LBCookieStickinessPolicy``.
 
         see
@@ -445,16 +368,7 @@ class CfnLoadBalancer(
     @lb_cookie_stickiness_policy.setter
     def lb_cookie_stickiness_policy(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "lbCookieStickinessPolicy", value)
 
@@ -476,12 +390,7 @@ class CfnLoadBalancer(
     @jsii.member(jsii_name="policies")
     def policies(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["PoliciesProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PoliciesProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.Policies``.
 
         see
@@ -492,12 +401,7 @@ class CfnLoadBalancer(
     @policies.setter
     def policies(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["PoliciesProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PoliciesProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "policies", value)
 
@@ -1155,67 +1059,18 @@ class CfnLoadBalancerProps:
     def __init__(
         self,
         *,
-        listeners: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnLoadBalancer.ListenersProperty", _IResolvable_9ceae33e]
-            ],
-        ],
-        access_logging_policy: typing.Optional[
-            typing.Union[
-                "CfnLoadBalancer.AccessLoggingPolicyProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
-        app_cookie_stickiness_policy: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnLoadBalancer.AppCookieStickinessPolicyProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        listeners: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.ListenersProperty", _IResolvable_9ceae33e]]],
+        access_logging_policy: typing.Optional[typing.Union["CfnLoadBalancer.AccessLoggingPolicyProperty", _IResolvable_9ceae33e]] = None,
+        app_cookie_stickiness_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]] = None,
         availability_zones: typing.Optional[typing.List[str]] = None,
-        connection_draining_policy: typing.Optional[
-            typing.Union[
-                "CfnLoadBalancer.ConnectionDrainingPolicyProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ] = None,
-        connection_settings: typing.Optional[
-            typing.Union[
-                "CfnLoadBalancer.ConnectionSettingsProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        connection_draining_policy: typing.Optional[typing.Union["CfnLoadBalancer.ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]] = None,
+        connection_settings: typing.Optional[typing.Union["CfnLoadBalancer.ConnectionSettingsProperty", _IResolvable_9ceae33e]] = None,
         cross_zone: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        health_check: typing.Optional[
-            typing.Union["CfnLoadBalancer.HealthCheckProperty", _IResolvable_9ceae33e]
-        ] = None,
+        health_check: typing.Optional[typing.Union["CfnLoadBalancer.HealthCheckProperty", _IResolvable_9ceae33e]] = None,
         instances: typing.Optional[typing.List[str]] = None,
-        lb_cookie_stickiness_policy: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnLoadBalancer.LBCookieStickinessPolicyProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        lb_cookie_stickiness_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]] = None,
         load_balancer_name: typing.Optional[str] = None,
-        policies: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnLoadBalancer.PoliciesProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        policies: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.PoliciesProperty", _IResolvable_9ceae33e]]]] = None,
         scheme: typing.Optional[str] = None,
         security_groups: typing.Optional[typing.List[str]] = None,
         subnets: typing.Optional[typing.List[str]] = None,
@@ -1280,12 +1135,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def listeners(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union["CfnLoadBalancer.ListenersProperty", _IResolvable_9ceae33e]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.ListenersProperty", _IResolvable_9ceae33e]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.Listeners``.
 
         see
@@ -1296,11 +1146,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def access_logging_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnLoadBalancer.AccessLoggingPolicyProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnLoadBalancer.AccessLoggingPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.AccessLoggingPolicy``.
 
         see
@@ -1311,17 +1157,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def app_cookie_stickiness_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnLoadBalancer.AppCookieStickinessPolicyProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.AppCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.AppCookieStickinessPolicy``.
 
         see
@@ -1341,11 +1177,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def connection_draining_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnLoadBalancer.ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnLoadBalancer.ConnectionDrainingPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.ConnectionDrainingPolicy``.
 
         see
@@ -1356,11 +1188,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def connection_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnLoadBalancer.ConnectionSettingsProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnLoadBalancer.ConnectionSettingsProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.ConnectionSettings``.
 
         see
@@ -1380,9 +1208,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def health_check(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnLoadBalancer.HealthCheckProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnLoadBalancer.HealthCheckProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.HealthCheck``.
 
         see
@@ -1402,17 +1228,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def lb_cookie_stickiness_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnLoadBalancer.LBCookieStickinessPolicyProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.LBCookieStickinessPolicyProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.LBCookieStickinessPolicy``.
 
         see
@@ -1432,14 +1248,7 @@ class CfnLoadBalancerProps:
     @builtins.property
     def policies(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnLoadBalancer.PoliciesProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLoadBalancer.PoliciesProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticLoadBalancing::LoadBalancer.Policies``.
 
         see
@@ -1795,9 +1604,7 @@ class LoadBalancer(
         self,
         *,
         external_port: jsii.Number,
-        allow_connections_from: typing.Optional[
-            typing.List[_IConnectable_a587039f]
-        ] = None,
+        allow_connections_from: typing.Optional[typing.List[_IConnectable_a587039f]] = None,
         external_protocol: typing.Optional["LoadBalancingProtocol"] = None,
         internal_port: typing.Optional[jsii.Number] = None,
         internal_protocol: typing.Optional["LoadBalancingProtocol"] = None,
@@ -1947,9 +1754,7 @@ class LoadBalancerListener:
         self,
         *,
         external_port: jsii.Number,
-        allow_connections_from: typing.Optional[
-            typing.List[_IConnectable_a587039f]
-        ] = None,
+        allow_connections_from: typing.Optional[typing.List[_IConnectable_a587039f]] = None,
         external_protocol: typing.Optional["LoadBalancingProtocol"] = None,
         internal_port: typing.Optional[jsii.Number] = None,
         internal_protocol: typing.Optional["LoadBalancingProtocol"] = None,
