@@ -12,18 +12,16 @@ from .._jsii import *
 
 from ..aws_ec2 import Instance as _Instance_024cd2a8
 from ..aws_elasticloadbalancingv2 import (
-    LoadBalancerTargetProps as _LoadBalancerTargetProps_80dbd4a5,
-    IApplicationTargetGroup as _IApplicationTargetGroup_1bf77cc5,
-    INetworkTargetGroup as _INetworkTargetGroup_1183b98f,
     IApplicationLoadBalancerTarget as _IApplicationLoadBalancerTarget_079c540c,
+    IApplicationTargetGroup as _IApplicationTargetGroup_1bf77cc5,
     INetworkLoadBalancerTarget as _INetworkLoadBalancerTarget_c44e1c1e,
+    INetworkTargetGroup as _INetworkTargetGroup_1183b98f,
+    LoadBalancerTargetProps as _LoadBalancerTargetProps_80dbd4a5,
 )
 from ..aws_lambda import IFunction as _IFunction_1c1de0bc
 
 
-@jsii.implements(
-    _IApplicationLoadBalancerTarget_079c540c, _INetworkLoadBalancerTarget_c44e1c1e
-)
+@jsii.implements(_IApplicationLoadBalancerTarget_079c540c, _INetworkLoadBalancerTarget_c44e1c1e)
 class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_targets.InstanceIdTarget",
@@ -107,9 +105,7 @@ class InstanceTarget(
         jsii.create(InstanceTarget, self, [instance, port])
 
 
-@jsii.implements(
-    _IApplicationLoadBalancerTarget_079c540c, _INetworkLoadBalancerTarget_c44e1c1e
-)
+@jsii.implements(_IApplicationLoadBalancerTarget_079c540c, _INetworkLoadBalancerTarget_c44e1c1e)
 class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_targets.IpTarget",
