@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -188,21 +188,10 @@ class CfnPolicy(
         remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e],
         resource_type: str,
         security_service_policy_data: typing.Any,
-        delete_all_policy_resources: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        exclude_map: typing.Optional[
-            typing.Union["IEMapProperty", _IResolvable_9ceae33e]
-        ] = None,
-        include_map: typing.Optional[
-            typing.Union["IEMapProperty", _IResolvable_9ceae33e]
-        ] = None,
-        resource_tags: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        delete_all_policy_resources: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        exclude_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]] = None,
+        include_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]] = None,
+        resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
         resource_type_list: typing.Optional[typing.List[str]] = None,
         tags: typing.Optional[typing.List["PolicyTagProperty"]] = None,
     ) -> None:
@@ -421,12 +410,7 @@ class CfnPolicy(
     @jsii.member(jsii_name="resourceTags")
     def resource_tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::FMS::Policy.ResourceTags``.
 
         see
@@ -437,12 +421,7 @@ class CfnPolicy(
     @resource_tags.setter
     def resource_tags(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "resourceTags", value)
 
@@ -505,6 +484,7 @@ class CfnPolicy(
             """
             ...
 
+
     class _IEMapPropertyProxy:
         """
         see
@@ -657,23 +637,10 @@ class CfnPolicyProps:
         remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e],
         resource_type: str,
         security_service_policy_data: typing.Any,
-        delete_all_policy_resources: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        exclude_map: typing.Optional[
-            typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
-        ] = None,
-        include_map: typing.Optional[
-            typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
-        ] = None,
-        resource_tags: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        delete_all_policy_resources: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        exclude_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
+        include_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
+        resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
         resource_type_list: typing.Optional[typing.List[str]] = None,
         tags: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]] = None,
     ) -> None:
@@ -773,9 +740,7 @@ class CfnPolicyProps:
     @builtins.property
     def exclude_map(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.ExcludeMap``.
 
         see
@@ -786,9 +751,7 @@ class CfnPolicyProps:
     @builtins.property
     def include_map(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.IncludeMap``.
 
         see
@@ -799,14 +762,7 @@ class CfnPolicyProps:
     @builtins.property
     def resource_tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::FMS::Policy.ResourceTags``.
 
         see
