@@ -12,21 +12,21 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     Resource as _Resource_884d0774,
     ResourceProps as _ResourceProps_92be6f66,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_ec2 import (
-    ISecurityGroup as _ISecurityGroup_d72ab8e8,
     Connections as _Connections_231f38b5,
-    IVpc as _IVpc_3795853f,
     IConnectable as _IConnectable_a587039f,
+    ISecurityGroup as _ISecurityGroup_d72ab8e8,
     ISubnet as _ISubnet_7f5367e6,
+    IVpc as _IVpc_3795853f,
 )
 from ..aws_kms import IKey as _IKey_3336c79d
 
@@ -54,16 +54,12 @@ class CfnFileSystem(
         subnet_ids: typing.List[str],
         backup_id: typing.Optional[str] = None,
         kms_key_id: typing.Optional[str] = None,
-        lustre_configuration: typing.Optional[
-            typing.Union["LustreConfigurationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        lustre_configuration: typing.Optional[typing.Union["LustreConfigurationProperty", _IResolvable_9ceae33e]] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
         storage_capacity: typing.Optional[jsii.Number] = None,
         storage_type: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        windows_configuration: typing.Optional[
-            typing.Union["WindowsConfigurationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        windows_configuration: typing.Optional[typing.Union["WindowsConfigurationProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::FSx::FileSystem``.
 
@@ -205,9 +201,7 @@ class CfnFileSystem(
     @jsii.member(jsii_name="lustreConfiguration")
     def lustre_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["LustreConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["LustreConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::FSx::FileSystem.LustreConfiguration``.
 
         see
@@ -218,9 +212,7 @@ class CfnFileSystem(
     @lustre_configuration.setter
     def lustre_configuration(
         self,
-        value: typing.Optional[
-            typing.Union["LustreConfigurationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["LustreConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "lustreConfiguration", value)
 
@@ -270,9 +262,7 @@ class CfnFileSystem(
     @jsii.member(jsii_name="windowsConfiguration")
     def windows_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["WindowsConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["WindowsConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::FSx::FileSystem.WindowsConfiguration``.
 
         see
@@ -283,9 +273,7 @@ class CfnFileSystem(
     @windows_configuration.setter
     def windows_configuration(
         self,
-        value: typing.Optional[
-            typing.Union["WindowsConfigurationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["WindowsConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "windowsConfiguration", value)
 
@@ -311,9 +299,7 @@ class CfnFileSystem(
             *,
             auto_import_policy: typing.Optional[str] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
-            copy_tags_to_backups: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            copy_tags_to_backups: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             daily_automatic_backup_start_time: typing.Optional[str] = None,
             deployment_type: typing.Optional[str] = None,
             export_path: typing.Optional[str] = None,
@@ -341,15 +327,11 @@ class CfnFileSystem(
             if auto_import_policy is not None:
                 self._values["auto_import_policy"] = auto_import_policy
             if automatic_backup_retention_days is not None:
-                self._values[
-                    "automatic_backup_retention_days"
-                ] = automatic_backup_retention_days
+                self._values["automatic_backup_retention_days"] = automatic_backup_retention_days
             if copy_tags_to_backups is not None:
                 self._values["copy_tags_to_backups"] = copy_tags_to_backups
             if daily_automatic_backup_start_time is not None:
-                self._values[
-                    "daily_automatic_backup_start_time"
-                ] = daily_automatic_backup_start_time
+                self._values["daily_automatic_backup_start_time"] = daily_automatic_backup_start_time
             if deployment_type is not None:
                 self._values["deployment_type"] = deployment_type
             if export_path is not None:
@@ -359,13 +341,9 @@ class CfnFileSystem(
             if import_path is not None:
                 self._values["import_path"] = import_path
             if per_unit_storage_throughput is not None:
-                self._values[
-                    "per_unit_storage_throughput"
-                ] = per_unit_storage_throughput
+                self._values["per_unit_storage_throughput"] = per_unit_storage_throughput
             if weekly_maintenance_start_time is not None:
-                self._values[
-                    "weekly_maintenance_start_time"
-                ] = weekly_maintenance_start_time
+                self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
         @builtins.property
         def auto_import_policy(self) -> typing.Optional[str]:
@@ -510,13 +488,9 @@ class CfnFileSystem(
             if domain_name is not None:
                 self._values["domain_name"] = domain_name
             if file_system_administrators_group is not None:
-                self._values[
-                    "file_system_administrators_group"
-                ] = file_system_administrators_group
+                self._values["file_system_administrators_group"] = file_system_administrators_group
             if organizational_unit_distinguished_name is not None:
-                self._values[
-                    "organizational_unit_distinguished_name"
-                ] = organizational_unit_distinguished_name
+                self._values["organizational_unit_distinguished_name"] = organizational_unit_distinguished_name
             if password is not None:
                 self._values["password"] = password
             if user_name is not None:
@@ -608,18 +582,11 @@ class CfnFileSystem(
             *,
             active_directory_id: typing.Optional[str] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
-            copy_tags_to_backups: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            copy_tags_to_backups: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             daily_automatic_backup_start_time: typing.Optional[str] = None,
             deployment_type: typing.Optional[str] = None,
             preferred_subnet_id: typing.Optional[str] = None,
-            self_managed_active_directory_configuration: typing.Optional[
-                typing.Union[
-                    "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            self_managed_active_directory_configuration: typing.Optional[typing.Union["CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty", _IResolvable_9ceae33e]] = None,
             throughput_capacity: typing.Optional[jsii.Number] = None,
             weekly_maintenance_start_time: typing.Optional[str] = None,
         ) -> None:
@@ -641,29 +608,21 @@ class CfnFileSystem(
             if active_directory_id is not None:
                 self._values["active_directory_id"] = active_directory_id
             if automatic_backup_retention_days is not None:
-                self._values[
-                    "automatic_backup_retention_days"
-                ] = automatic_backup_retention_days
+                self._values["automatic_backup_retention_days"] = automatic_backup_retention_days
             if copy_tags_to_backups is not None:
                 self._values["copy_tags_to_backups"] = copy_tags_to_backups
             if daily_automatic_backup_start_time is not None:
-                self._values[
-                    "daily_automatic_backup_start_time"
-                ] = daily_automatic_backup_start_time
+                self._values["daily_automatic_backup_start_time"] = daily_automatic_backup_start_time
             if deployment_type is not None:
                 self._values["deployment_type"] = deployment_type
             if preferred_subnet_id is not None:
                 self._values["preferred_subnet_id"] = preferred_subnet_id
             if self_managed_active_directory_configuration is not None:
-                self._values[
-                    "self_managed_active_directory_configuration"
-                ] = self_managed_active_directory_configuration
+                self._values["self_managed_active_directory_configuration"] = self_managed_active_directory_configuration
             if throughput_capacity is not None:
                 self._values["throughput_capacity"] = throughput_capacity
             if weekly_maintenance_start_time is not None:
-                self._values[
-                    "weekly_maintenance_start_time"
-                ] = weekly_maintenance_start_time
+                self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
         @builtins.property
         def active_directory_id(self) -> typing.Optional[str]:
@@ -724,12 +683,7 @@ class CfnFileSystem(
         @builtins.property
         def self_managed_active_directory_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnFileSystem.WindowsConfigurationProperty.SelfManagedActiveDirectoryConfiguration``.
 
             see
@@ -791,20 +745,12 @@ class CfnFileSystemProps:
         subnet_ids: typing.List[str],
         backup_id: typing.Optional[str] = None,
         kms_key_id: typing.Optional[str] = None,
-        lustre_configuration: typing.Optional[
-            typing.Union[
-                "CfnFileSystem.LustreConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        lustre_configuration: typing.Optional[typing.Union["CfnFileSystem.LustreConfigurationProperty", _IResolvable_9ceae33e]] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
         storage_capacity: typing.Optional[jsii.Number] = None,
         storage_type: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        windows_configuration: typing.Optional[
-            typing.Union[
-                "CfnFileSystem.WindowsConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        windows_configuration: typing.Optional[typing.Union["CfnFileSystem.WindowsConfigurationProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::FSx::FileSystem``.
 
@@ -882,9 +828,7 @@ class CfnFileSystemProps:
     @builtins.property
     def lustre_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnFileSystem.LustreConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnFileSystem.LustreConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::FSx::FileSystem.LustreConfiguration``.
 
         see
@@ -931,11 +875,7 @@ class CfnFileSystemProps:
     @builtins.property
     def windows_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnFileSystem.WindowsConfigurationProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnFileSystem.WindowsConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::FSx::FileSystem.WindowsConfiguration``.
 
         see
@@ -1239,9 +1179,7 @@ class LustreConfiguration:
         if per_unit_storage_throughput is not None:
             self._values["per_unit_storage_throughput"] = per_unit_storage_throughput
         if weekly_maintenance_start_time is not None:
-            self._values[
-                "weekly_maintenance_start_time"
-            ] = weekly_maintenance_start_time
+            self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
     @builtins.property
     def deployment_type(self) -> "LustreDeploymentType":
