@@ -21,6 +21,7 @@ from ..aws_iam import (
     IRole as _IRole_e69bbae4, PolicyStatement as _PolicyStatement_f75dc775
 )
 from ..aws_lambda import (
+    FileSystem as _FileSystem_132c0ce7,
     Function as _Function_c537766c,
     FunctionOptions as _FunctionOptions_83fb7178,
     IDestination as _IDestination_7081f282,
@@ -56,12 +57,14 @@ class PythonFunction(
         index: typing.Optional[str] = None,
         runtime: typing.Optional[_Runtime_8b970b80] = None,
         allow_all_outbound: typing.Optional[bool] = None,
+        allow_public_subnet: typing.Optional[bool] = None,
         current_version_options: typing.Optional[_VersionOptions_9a55a63d] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
         dead_letter_queue_enabled: typing.Optional[bool] = None,
         description: typing.Optional[str] = None,
         environment: typing.Optional[typing.Mapping[str, str]] = None,
         events: typing.Optional[typing.List[_IEventSource_0e6bcb85]] = None,
+        filesystem: typing.Optional[_FileSystem_132c0ce7] = None,
         function_name: typing.Optional[str] = None,
         initial_policy: typing.Optional[typing.List[_PolicyStatement_f75dc775]] = None,
         layers: typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]] = None,
@@ -92,12 +95,14 @@ class PythonFunction(
         :param index: The path (relative to entry) to the index file containing the exported handler. Default: index.py
         :param runtime: The runtime environment. Only runtimes of the Python family are supported. Default: lambda.Runtime.PYTHON_3_7
         :param allow_all_outbound: Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
+        :param allow_public_subnet: Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
         :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
+        :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
         :param initial_policy: Initial policy statements to add to the created Lambda Role. You can call ``addToRolePolicy`` to the created lambda to add statements post creation. Default: - No policy statements are added to the created Lambda role.
         :param layers: A list of layers to add to the function's execution environment. You can configure your Lambda function to pull in additional code during initialization in the form of layers. Layers are packages of libraries or other dependencies that can be used by mulitple functions. Default: - No layers.
@@ -129,12 +134,14 @@ class PythonFunction(
             index=index,
             runtime=runtime,
             allow_all_outbound=allow_all_outbound,
+            allow_public_subnet=allow_public_subnet,
             current_version_options=current_version_options,
             dead_letter_queue=dead_letter_queue,
             dead_letter_queue_enabled=dead_letter_queue_enabled,
             description=description,
             environment=environment,
             events=events,
+            filesystem=filesystem,
             function_name=function_name,
             initial_policy=initial_policy,
             layers=layers,
@@ -170,12 +177,14 @@ class PythonFunction(
         "on_success": "onSuccess",
         "retry_attempts": "retryAttempts",
         "allow_all_outbound": "allowAllOutbound",
+        "allow_public_subnet": "allowPublicSubnet",
         "current_version_options": "currentVersionOptions",
         "dead_letter_queue": "deadLetterQueue",
         "dead_letter_queue_enabled": "deadLetterQueueEnabled",
         "description": "description",
         "environment": "environment",
         "events": "events",
+        "filesystem": "filesystem",
         "function_name": "functionName",
         "initial_policy": "initialPolicy",
         "layers": "layers",
@@ -208,12 +217,14 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         on_success: typing.Optional[_IDestination_7081f282] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
         allow_all_outbound: typing.Optional[bool] = None,
+        allow_public_subnet: typing.Optional[bool] = None,
         current_version_options: typing.Optional[_VersionOptions_9a55a63d] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
         dead_letter_queue_enabled: typing.Optional[bool] = None,
         description: typing.Optional[str] = None,
         environment: typing.Optional[typing.Mapping[str, str]] = None,
         events: typing.Optional[typing.List[_IEventSource_0e6bcb85]] = None,
+        filesystem: typing.Optional[_FileSystem_132c0ce7] = None,
         function_name: typing.Optional[str] = None,
         initial_policy: typing.Optional[typing.List[_PolicyStatement_f75dc775]] = None,
         layers: typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]] = None,
@@ -243,12 +254,14 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         :param allow_all_outbound: Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
+        :param allow_public_subnet: Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
         :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
+        :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
         :param initial_policy: Initial policy statements to add to the created Lambda Role. You can call ``addToRolePolicy`` to the created lambda to add statements post creation. Default: - No policy statements are added to the created Lambda role.
         :param layers: A list of layers to add to the function's execution environment. You can configure your Lambda function to pull in additional code during initialization in the form of layers. Layers are packages of libraries or other dependencies that can be used by mulitple functions. Default: - No layers.
@@ -293,6 +306,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
             self._values["retry_attempts"] = retry_attempts
         if allow_all_outbound is not None:
             self._values["allow_all_outbound"] = allow_all_outbound
+        if allow_public_subnet is not None:
+            self._values["allow_public_subnet"] = allow_public_subnet
         if current_version_options is not None:
             self._values["current_version_options"] = current_version_options
         if dead_letter_queue is not None:
@@ -305,6 +320,8 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
             self._values["environment"] = environment
         if events is not None:
             self._values["events"] = events
+        if filesystem is not None:
+            self._values["filesystem"] = filesystem
         if function_name is not None:
             self._values["function_name"] = function_name
         if initial_policy is not None:
@@ -415,6 +432,22 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         """
         return self._values.get("allow_all_outbound")
 
+    @builtins.property
+    def allow_public_subnet(self) -> typing.Optional[bool]:
+        """Lambda Functions in a public subnet can NOT access the internet.
+
+        Use this property to acknowledge this limitation and still place the function in a public subnet.
+
+        default
+        :default: false
+
+        see
+        :see: https://stackoverflow.com/questions/52992085/why-cant-an-aws-lambda-function-inside-a-public-subnet-in-a-vpc-connect-to-the/52994841#52994841
+        stability
+        :stability: experimental
+        """
+        return self._values.get("allow_public_subnet")
+
     @builtins.property
     def current_version_options(self) -> typing.Optional[_VersionOptions_9a55a63d]:
         """Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method.
@@ -496,6 +529,18 @@ class PythonFunctionProps(_FunctionOptions_83fb7178):
         """
         return self._values.get("events")
 
+    @builtins.property
+    def filesystem(self) -> typing.Optional[_FileSystem_132c0ce7]:
+        """The filesystem configuration for the lambda function.
+
+        default
+        :default: - will not mount any filesystem
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("filesystem")
+
     @builtins.property
     def function_name(self) -> typing.Optional[str]:
         """A name for the function.
