@@ -13,10 +13,10 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -40,19 +40,10 @@ class CfnJobTemplate(
         id: str,
         *,
         settings_json: typing.Any,
-        acceleration_settings: typing.Optional[
-            typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        acceleration_settings: typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
         category: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
-        hop_destinations: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
         name: typing.Optional[str] = None,
         priority: typing.Optional[jsii.Number] = None,
         queue: typing.Optional[str] = None,
@@ -166,9 +157,7 @@ class CfnJobTemplate(
     @jsii.member(jsii_name="accelerationSettings")
     def acceleration_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]]:
         """``AWS::MediaConvert::JobTemplate.AccelerationSettings``.
 
         see
@@ -179,9 +168,7 @@ class CfnJobTemplate(
     @acceleration_settings.setter
     def acceleration_settings(
         self,
-        value: typing.Optional[
-            typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "accelerationSettings", value)
 
@@ -217,12 +204,7 @@ class CfnJobTemplate(
     @jsii.member(jsii_name="hopDestinations")
     def hop_destinations(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::MediaConvert::JobTemplate.HopDestinations``.
 
         see
@@ -233,14 +215,7 @@ class CfnJobTemplate(
     @hop_destinations.setter
     def hop_destinations(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "hopDestinations", value)
 
@@ -430,23 +405,10 @@ class CfnJobTemplateProps:
         self,
         *,
         settings_json: typing.Any,
-        acceleration_settings: typing.Optional[
-            typing.Union[
-                "CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        acceleration_settings: typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
         category: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
-        hop_destinations: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
         name: typing.Optional[str] = None,
         priority: typing.Optional[jsii.Number] = None,
         queue: typing.Optional[str] = None,
@@ -503,11 +465,7 @@ class CfnJobTemplateProps:
     @builtins.property
     def acceleration_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]]:
         """``AWS::MediaConvert::JobTemplate.AccelerationSettings``.
 
         see
@@ -536,16 +494,7 @@ class CfnJobTemplateProps:
     @builtins.property
     def hop_destinations(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::MediaConvert::JobTemplate.HopDestinations``.
 
         see
