@@ -13,10 +13,10 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -39,28 +39,16 @@ class CfnCluster(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        broker_node_group_info: typing.Union[
-            "BrokerNodeGroupInfoProperty", _IResolvable_9ceae33e
-        ],
+        broker_node_group_info: typing.Union["BrokerNodeGroupInfoProperty", _IResolvable_9ceae33e],
         cluster_name: str,
         kafka_version: str,
         number_of_broker_nodes: jsii.Number,
-        client_authentication: typing.Optional[
-            typing.Union["ClientAuthenticationProperty", _IResolvable_9ceae33e]
-        ] = None,
-        configuration_info: typing.Optional[
-            typing.Union["ConfigurationInfoProperty", _IResolvable_9ceae33e]
-        ] = None,
-        encryption_info: typing.Optional[
-            typing.Union["EncryptionInfoProperty", _IResolvable_9ceae33e]
-        ] = None,
+        client_authentication: typing.Optional[typing.Union["ClientAuthenticationProperty", _IResolvable_9ceae33e]] = None,
+        configuration_info: typing.Optional[typing.Union["ConfigurationInfoProperty", _IResolvable_9ceae33e]] = None,
+        encryption_info: typing.Optional[typing.Union["EncryptionInfoProperty", _IResolvable_9ceae33e]] = None,
         enhanced_monitoring: typing.Optional[str] = None,
-        logging_info: typing.Optional[
-            typing.Union["LoggingInfoProperty", _IResolvable_9ceae33e]
-        ] = None,
-        open_monitoring: typing.Optional[
-            typing.Union["OpenMonitoringProperty", _IResolvable_9ceae33e]
-        ] = None,
+        logging_info: typing.Optional[typing.Union["LoggingInfoProperty", _IResolvable_9ceae33e]] = None,
+        open_monitoring: typing.Optional[typing.Union["OpenMonitoringProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::MSK::Cluster``.
@@ -200,9 +188,7 @@ class CfnCluster(
     @jsii.member(jsii_name="clientAuthentication")
     def client_authentication(
         self,
-    ) -> typing.Optional[
-        typing.Union["ClientAuthenticationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["ClientAuthenticationProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.ClientAuthentication``.
 
         see
@@ -213,9 +199,7 @@ class CfnCluster(
     @client_authentication.setter
     def client_authentication(
         self,
-        value: typing.Optional[
-            typing.Union["ClientAuthenticationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["ClientAuthenticationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "clientAuthentication", value)
 
@@ -223,9 +207,7 @@ class CfnCluster(
     @jsii.member(jsii_name="configurationInfo")
     def configuration_info(
         self,
-    ) -> typing.Optional[
-        typing.Union["ConfigurationInfoProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["ConfigurationInfoProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.ConfigurationInfo``.
 
         see
@@ -236,9 +218,7 @@ class CfnCluster(
     @configuration_info.setter
     def configuration_info(
         self,
-        value: typing.Optional[
-            typing.Union["ConfigurationInfoProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["ConfigurationInfoProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "configurationInfo", value)
 
@@ -257,9 +237,7 @@ class CfnCluster(
     @encryption_info.setter
     def encryption_info(
         self,
-        value: typing.Optional[
-            typing.Union["EncryptionInfoProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["EncryptionInfoProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "encryptionInfo", value)
 
@@ -292,9 +270,7 @@ class CfnCluster(
     @logging_info.setter
     def logging_info(
         self,
-        value: typing.Optional[
-            typing.Union["LoggingInfoProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["LoggingInfoProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "loggingInfo", value)
 
@@ -313,9 +289,7 @@ class CfnCluster(
     @open_monitoring.setter
     def open_monitoring(
         self,
-        value: typing.Optional[
-            typing.Union["OpenMonitoringProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["OpenMonitoringProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "openMonitoring", value)
 
@@ -332,15 +306,9 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            cloud_watch_logs: typing.Optional[
-                typing.Union["CfnCluster.CloudWatchLogsProperty", _IResolvable_9ceae33e]
-            ] = None,
-            firehose: typing.Optional[
-                typing.Union["CfnCluster.FirehoseProperty", _IResolvable_9ceae33e]
-            ] = None,
-            s3: typing.Optional[
-                typing.Union["CfnCluster.S3Property", _IResolvable_9ceae33e]
-            ] = None,
+            cloud_watch_logs: typing.Optional[typing.Union["CfnCluster.CloudWatchLogsProperty", _IResolvable_9ceae33e]] = None,
+            firehose: typing.Optional[typing.Union["CfnCluster.FirehoseProperty", _IResolvable_9ceae33e]] = None,
+            s3: typing.Optional[typing.Union["CfnCluster.S3Property", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param cloud_watch_logs: ``CfnCluster.BrokerLogsProperty.CloudWatchLogs``.
@@ -361,9 +329,7 @@ class CfnCluster(
         @builtins.property
         def cloud_watch_logs(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.CloudWatchLogsProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.CloudWatchLogsProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.BrokerLogsProperty.CloudWatchLogs``.
 
             see
@@ -374,9 +340,7 @@ class CfnCluster(
         @builtins.property
         def firehose(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.FirehoseProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.FirehoseProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.BrokerLogsProperty.Firehose``.
 
             see
@@ -387,9 +351,7 @@ class CfnCluster(
         @builtins.property
         def s3(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.S3Property", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.S3Property", _IResolvable_9ceae33e]]:
             """``CfnCluster.BrokerLogsProperty.S3``.
 
             see
@@ -427,9 +389,7 @@ class CfnCluster(
             instance_type: str,
             broker_az_distribution: typing.Optional[str] = None,
             security_groups: typing.Optional[typing.List[str]] = None,
-            storage_info: typing.Optional[
-                typing.Union["CfnCluster.StorageInfoProperty", _IResolvable_9ceae33e]
-            ] = None,
+            storage_info: typing.Optional[typing.Union["CfnCluster.StorageInfoProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param client_subnets: ``CfnCluster.BrokerNodeGroupInfoProperty.ClientSubnets``.
@@ -491,9 +451,7 @@ class CfnCluster(
         @builtins.property
         def storage_info(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.StorageInfoProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.StorageInfoProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.BrokerNodeGroupInfoProperty.StorageInfo``.
 
             see
@@ -521,9 +479,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            tls: typing.Optional[
-                typing.Union["CfnCluster.TlsProperty", _IResolvable_9ceae33e]
-            ] = None,
+            tls: typing.Optional[typing.Union["CfnCluster.TlsProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param tls: ``CfnCluster.ClientAuthenticationProperty.Tls``.
@@ -538,9 +494,7 @@ class CfnCluster(
         @builtins.property
         def tls(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.TlsProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.TlsProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.ClientAuthenticationProperty.Tls``.
 
             see
@@ -745,9 +699,7 @@ class CfnCluster(
             self,
             *,
             client_broker: typing.Optional[str] = None,
-            in_cluster: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            in_cluster: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param client_broker: ``CfnCluster.EncryptionInTransitProperty.ClientBroker``.
@@ -805,16 +757,8 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            encryption_at_rest: typing.Optional[
-                typing.Union[
-                    "CfnCluster.EncryptionAtRestProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            encryption_in_transit: typing.Optional[
-                typing.Union[
-                    "CfnCluster.EncryptionInTransitProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            encryption_at_rest: typing.Optional[typing.Union["CfnCluster.EncryptionAtRestProperty", _IResolvable_9ceae33e]] = None,
+            encryption_in_transit: typing.Optional[typing.Union["CfnCluster.EncryptionInTransitProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param encryption_at_rest: ``CfnCluster.EncryptionInfoProperty.EncryptionAtRest``.
@@ -832,9 +776,7 @@ class CfnCluster(
         @builtins.property
         def encryption_at_rest(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.EncryptionAtRestProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.EncryptionAtRestProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.EncryptionInfoProperty.EncryptionAtRest``.
 
             see
@@ -845,11 +787,7 @@ class CfnCluster(
         @builtins.property
         def encryption_in_transit(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnCluster.EncryptionInTransitProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.EncryptionInTransitProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.EncryptionInfoProperty.EncryptionInTransit``.
 
             see
@@ -970,9 +908,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            broker_logs: typing.Union[
-                "CfnCluster.BrokerLogsProperty", _IResolvable_9ceae33e
-            ],
+            broker_logs: typing.Union["CfnCluster.BrokerLogsProperty", _IResolvable_9ceae33e],
         ) -> None:
             """
             :param broker_logs: ``CfnCluster.LoggingInfoProperty.BrokerLogs``.
@@ -1054,9 +990,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            prometheus: typing.Union[
-                "CfnCluster.PrometheusProperty", _IResolvable_9ceae33e
-            ],
+            prometheus: typing.Union["CfnCluster.PrometheusProperty", _IResolvable_9ceae33e],
         ) -> None:
             """
             :param prometheus: ``CfnCluster.OpenMonitoringProperty.Prometheus``.
@@ -1099,12 +1033,8 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            jmx_exporter: typing.Optional[
-                typing.Union["CfnCluster.JmxExporterProperty", _IResolvable_9ceae33e]
-            ] = None,
-            node_exporter: typing.Optional[
-                typing.Union["CfnCluster.NodeExporterProperty", _IResolvable_9ceae33e]
-            ] = None,
+            jmx_exporter: typing.Optional[typing.Union["CfnCluster.JmxExporterProperty", _IResolvable_9ceae33e]] = None,
+            node_exporter: typing.Optional[typing.Union["CfnCluster.NodeExporterProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param jmx_exporter: ``CfnCluster.PrometheusProperty.JmxExporter``.
@@ -1122,9 +1052,7 @@ class CfnCluster(
         @builtins.property
         def jmx_exporter(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.JmxExporterProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.JmxExporterProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.PrometheusProperty.JmxExporter``.
 
             see
@@ -1135,9 +1063,7 @@ class CfnCluster(
         @builtins.property
         def node_exporter(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.NodeExporterProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.NodeExporterProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.PrometheusProperty.NodeExporter``.
 
             see
@@ -1232,9 +1158,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            ebs_storage_info: typing.Optional[
-                typing.Union["CfnCluster.EBSStorageInfoProperty", _IResolvable_9ceae33e]
-            ] = None,
+            ebs_storage_info: typing.Optional[typing.Union["CfnCluster.EBSStorageInfoProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param ebs_storage_info: ``CfnCluster.StorageInfoProperty.EBSStorageInfo``.
@@ -1249,9 +1173,7 @@ class CfnCluster(
         @builtins.property
         def ebs_storage_info(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnCluster.EBSStorageInfoProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnCluster.EBSStorageInfoProperty", _IResolvable_9ceae33e]]:
             """``CfnCluster.StorageInfoProperty.EBSStorageInfo``.
 
             see
@@ -1289,9 +1211,7 @@ class CfnCluster(
             """
             self._values = {}
             if certificate_authority_arn_list is not None:
-                self._values[
-                    "certificate_authority_arn_list"
-                ] = certificate_authority_arn_list
+                self._values["certificate_authority_arn_list"] = certificate_authority_arn_list
 
         @builtins.property
         def certificate_authority_arn_list(self) -> typing.Optional[typing.List[str]]:
@@ -1335,30 +1255,16 @@ class CfnClusterProps:
     def __init__(
         self,
         *,
-        broker_node_group_info: typing.Union[
-            "CfnCluster.BrokerNodeGroupInfoProperty", _IResolvable_9ceae33e
-        ],
+        broker_node_group_info: typing.Union["CfnCluster.BrokerNodeGroupInfoProperty", _IResolvable_9ceae33e],
         cluster_name: str,
         kafka_version: str,
         number_of_broker_nodes: jsii.Number,
-        client_authentication: typing.Optional[
-            typing.Union[
-                "CfnCluster.ClientAuthenticationProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
-        configuration_info: typing.Optional[
-            typing.Union["CfnCluster.ConfigurationInfoProperty", _IResolvable_9ceae33e]
-        ] = None,
-        encryption_info: typing.Optional[
-            typing.Union["CfnCluster.EncryptionInfoProperty", _IResolvable_9ceae33e]
-        ] = None,
+        client_authentication: typing.Optional[typing.Union["CfnCluster.ClientAuthenticationProperty", _IResolvable_9ceae33e]] = None,
+        configuration_info: typing.Optional[typing.Union["CfnCluster.ConfigurationInfoProperty", _IResolvable_9ceae33e]] = None,
+        encryption_info: typing.Optional[typing.Union["CfnCluster.EncryptionInfoProperty", _IResolvable_9ceae33e]] = None,
         enhanced_monitoring: typing.Optional[str] = None,
-        logging_info: typing.Optional[
-            typing.Union["CfnCluster.LoggingInfoProperty", _IResolvable_9ceae33e]
-        ] = None,
-        open_monitoring: typing.Optional[
-            typing.Union["CfnCluster.OpenMonitoringProperty", _IResolvable_9ceae33e]
-        ] = None,
+        logging_info: typing.Optional[typing.Union["CfnCluster.LoggingInfoProperty", _IResolvable_9ceae33e]] = None,
+        open_monitoring: typing.Optional[typing.Union["CfnCluster.OpenMonitoringProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::MSK::Cluster``.
@@ -1440,9 +1346,7 @@ class CfnClusterProps:
     @builtins.property
     def client_authentication(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCluster.ClientAuthenticationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCluster.ClientAuthenticationProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.ClientAuthentication``.
 
         see
@@ -1453,9 +1357,7 @@ class CfnClusterProps:
     @builtins.property
     def configuration_info(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCluster.ConfigurationInfoProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCluster.ConfigurationInfoProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.ConfigurationInfo``.
 
         see
@@ -1466,9 +1368,7 @@ class CfnClusterProps:
     @builtins.property
     def encryption_info(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCluster.EncryptionInfoProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCluster.EncryptionInfoProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.EncryptionInfo``.
 
         see
@@ -1488,9 +1388,7 @@ class CfnClusterProps:
     @builtins.property
     def logging_info(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCluster.LoggingInfoProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCluster.LoggingInfoProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.LoggingInfo``.
 
         see
@@ -1501,9 +1399,7 @@ class CfnClusterProps:
     @builtins.property
     def open_monitoring(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCluster.OpenMonitoringProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCluster.OpenMonitoringProperty", _IResolvable_9ceae33e]]:
         """``AWS::MSK::Cluster.OpenMonitoring``.
 
         see
