@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -45,14 +45,10 @@ class CfnDBCluster(
         db_cluster_identifier: typing.Optional[str] = None,
         db_cluster_parameter_group_name: typing.Optional[str] = None,
         db_subnet_group_name: typing.Optional[str] = None,
-        deletion_protection: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        deletion_protection: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         enable_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
         engine_version: typing.Optional[str] = None,
-        iam_auth_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        iam_auth_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         kms_key_id: typing.Optional[str] = None,
         port: typing.Optional[jsii.Number] = None,
         preferred_backup_window: typing.Optional[str] = None,
@@ -61,13 +57,9 @@ class CfnDBCluster(
         restore_type: typing.Optional[str] = None,
         snapshot_identifier: typing.Optional[str] = None,
         source_db_cluster_identifier: typing.Optional[str] = None,
-        storage_encrypted: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        storage_encrypted: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        use_latest_restorable_time: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        use_latest_restorable_time: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
     ) -> None:
         """Create a new ``AWS::Neptune::DBCluster``.
@@ -776,14 +768,10 @@ class CfnDBClusterProps:
         db_cluster_identifier: typing.Optional[str] = None,
         db_cluster_parameter_group_name: typing.Optional[str] = None,
         db_subnet_group_name: typing.Optional[str] = None,
-        deletion_protection: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        deletion_protection: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         enable_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
         engine_version: typing.Optional[str] = None,
-        iam_auth_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        iam_auth_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         kms_key_id: typing.Optional[str] = None,
         port: typing.Optional[jsii.Number] = None,
         preferred_backup_window: typing.Optional[str] = None,
@@ -792,13 +780,9 @@ class CfnDBClusterProps:
         restore_type: typing.Optional[str] = None,
         snapshot_identifier: typing.Optional[str] = None,
         source_db_cluster_identifier: typing.Optional[str] = None,
-        storage_encrypted: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        storage_encrypted: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        use_latest_restorable_time: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        use_latest_restorable_time: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Neptune::DBCluster``.
@@ -836,17 +820,13 @@ class CfnDBClusterProps:
         if db_cluster_identifier is not None:
             self._values["db_cluster_identifier"] = db_cluster_identifier
         if db_cluster_parameter_group_name is not None:
-            self._values[
-                "db_cluster_parameter_group_name"
-            ] = db_cluster_parameter_group_name
+            self._values["db_cluster_parameter_group_name"] = db_cluster_parameter_group_name
         if db_subnet_group_name is not None:
             self._values["db_subnet_group_name"] = db_subnet_group_name
         if deletion_protection is not None:
             self._values["deletion_protection"] = deletion_protection
         if enable_cloudwatch_logs_exports is not None:
-            self._values[
-                "enable_cloudwatch_logs_exports"
-            ] = enable_cloudwatch_logs_exports
+            self._values["enable_cloudwatch_logs_exports"] = enable_cloudwatch_logs_exports
         if engine_version is not None:
             self._values["engine_version"] = engine_version
         if iam_auth_enabled is not None:
@@ -1105,12 +1085,8 @@ class CfnDBInstance(
         id: str,
         *,
         db_instance_class: str,
-        allow_major_version_upgrade: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        auto_minor_version_upgrade: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        allow_major_version_upgrade: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        auto_minor_version_upgrade: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         availability_zone: typing.Optional[str] = None,
         db_cluster_identifier: typing.Optional[str] = None,
         db_instance_identifier: typing.Optional[str] = None,
@@ -1382,12 +1358,8 @@ class CfnDBInstanceProps:
         self,
         *,
         db_instance_class: str,
-        allow_major_version_upgrade: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        auto_minor_version_upgrade: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        allow_major_version_upgrade: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        auto_minor_version_upgrade: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         availability_zone: typing.Optional[str] = None,
         db_cluster_identifier: typing.Optional[str] = None,
         db_instance_identifier: typing.Optional[str] = None,
