@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -43,26 +43,15 @@ class CfnServer(
         instance_profile_arn: str,
         instance_type: str,
         service_role_arn: str,
-        associate_public_ip_address: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        associate_public_ip_address: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         backup_id: typing.Optional[str] = None,
         backup_retention_count: typing.Optional[jsii.Number] = None,
         custom_certificate: typing.Optional[str] = None,
         custom_domain: typing.Optional[str] = None,
         custom_private_key: typing.Optional[str] = None,
-        disable_automated_backup: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        disable_automated_backup: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         engine: typing.Optional[str] = None,
-        engine_attributes: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
         engine_model: typing.Optional[str] = None,
         engine_version: typing.Optional[str] = None,
         key_pair: typing.Optional[str] = None,
@@ -350,12 +339,7 @@ class CfnServer(
     @jsii.member(jsii_name="engineAttributes")
     def engine_attributes(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::OpsWorksCM::Server.EngineAttributes``.
 
         see
@@ -366,14 +350,7 @@ class CfnServer(
     @engine_attributes.setter
     def engine_attributes(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "engineAttributes", value)
 
@@ -578,28 +555,15 @@ class CfnServerProps:
         instance_profile_arn: str,
         instance_type: str,
         service_role_arn: str,
-        associate_public_ip_address: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        associate_public_ip_address: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         backup_id: typing.Optional[str] = None,
         backup_retention_count: typing.Optional[jsii.Number] = None,
         custom_certificate: typing.Optional[str] = None,
         custom_domain: typing.Optional[str] = None,
         custom_private_key: typing.Optional[str] = None,
-        disable_automated_backup: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        disable_automated_backup: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         engine: typing.Optional[str] = None,
-        engine_attributes: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
         engine_model: typing.Optional[str] = None,
         engine_version: typing.Optional[str] = None,
         key_pair: typing.Optional[str] = None,
@@ -785,14 +749,7 @@ class CfnServerProps:
     @builtins.property
     def engine_attributes(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::OpsWorksCM::Server.EngineAttributes``.
 
         see
