@@ -11,16 +11,15 @@ import publication
 from .._jsii import *
 
 from .. import (
-    Construct as _Construct_f50a3f53,
-    CfnResource as _CfnResource_7760e8e4,
-    IAsset as _IAsset_a3f13b15,
-    AssetOptions as _AssetOptions_b07b0eef,
     AssetHashType as _AssetHashType_16f7047a,
+    AssetOptions as _AssetOptions_b07b0eef,
     BundlingOptions as _BundlingOptions_0cab5223,
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IAsset as _IAsset_a3f13b15,
 )
 from ..assets import (
-    CopyOptions as _CopyOptions_65085089,
-    FollowMode as _FollowMode_f74e7125,
+    CopyOptions as _CopyOptions_65085089, FollowMode as _FollowMode_f74e7125
 )
 from ..aws_iam import IGrantable as _IGrantable_0fcfc53a
 from ..aws_s3 import IBucket as _IBucket_25bad983
