@@ -12,11 +12,11 @@ from .._jsii import *
 
 from ..aws_lambda import IFunction as _IFunction_1c1de0bc
 from ..aws_sns import (
-    TopicSubscriptionConfig as _TopicSubscriptionConfig_2ddb92c9,
     ITopic as _ITopic_ef0ebe0e,
     ITopicSubscription as _ITopicSubscription_5303fec1,
     SubscriptionFilter as _SubscriptionFilter_91537200,
     SubscriptionProtocol as _SubscriptionProtocol_3d1a4bcf,
+    TopicSubscriptionConfig as _TopicSubscriptionConfig_2ddb92c9,
 )
 from ..aws_sqs import IQueue as _IQueue_b743f559
 
@@ -40,9 +40,7 @@ class EmailSubscription(
         *,
         json: typing.Optional[bool] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param email_address: -
@@ -87,9 +85,7 @@ class LambdaSubscription(
         fn: _IFunction_1c1de0bc,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param fn: -
@@ -133,9 +129,7 @@ class SmsSubscription(
         phone_number: str,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param phone_number: -
@@ -180,9 +174,7 @@ class SqsSubscription(
         *,
         raw_message_delivery: typing.Optional[bool] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param queue: -
@@ -226,9 +218,7 @@ class SubscriptionProps:
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """Options to subscribing to an SNS topic.
 
@@ -306,9 +296,7 @@ class UrlSubscription(
         protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
         raw_message_delivery: typing.Optional[bool] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param url: -
@@ -356,9 +344,7 @@ class UrlSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
         protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
         raw_message_delivery: typing.Optional[bool] = None,
     ) -> None:
@@ -462,9 +448,7 @@ class EmailSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
         json: typing.Optional[bool] = None,
     ) -> None:
         """Options for email subscriptions.
@@ -549,9 +533,7 @@ class LambdaSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """Properties for a Lambda subscription.
 
@@ -620,9 +602,7 @@ class SmsSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """Options for SMS subscriptions.
 
@@ -692,9 +672,7 @@ class SqsSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[
-            typing.Mapping[str, _SubscriptionFilter_91537200]
-        ] = None,
+        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
         raw_message_delivery: typing.Optional[bool] = None,
     ) -> None:
         """Properties for an SQS subscription.
