@@ -11,26 +11,26 @@ import publication
 from .._jsii import *
 
 from ..cloud_assembly_schema import (
+    AmiContextQuery as _AmiContextQuery_f862ae87,
     ArtifactManifest as _ArtifactManifest_38498e6d,
     ArtifactType as _ArtifactType_9221e05d,
-    MetadataEntry as _MetadataEntry_1c069657,
-    AwsCloudFormationStackProperties as _AwsCloudFormationStackProperties_cbabc075,
-    AssetManifestProperties as _AssetManifestProperties_8c80271b,
-    TreeArtifactProperties as _TreeArtifactProperties_8af66c6c,
-    NestedCloudAssemblyProperties as _NestedCloudAssemblyProperties_2d939e98,
     AssemblyManifest as _AssemblyManifest_10a6b60e,
-    RuntimeInfo as _RuntimeInfo_847d082a,
-    MissingContext as _MissingContext_d8a115db,
-    AmiContextQuery as _AmiContextQuery_f862ae87,
+    AssetManifestProperties as _AssetManifestProperties_8c80271b,
     AvailabilityZonesContextQuery as _AvailabilityZonesContextQuery_9a5bac5f,
-    HostedZoneContextQuery as _HostedZoneContextQuery_42616509,
-    SSMParameterContextQuery as _SSMParameterContextQuery_f21616f8,
-    VpcContextQuery as _VpcContextQuery_65dc9cbf,
-    EndpointServiceAvailabilityZonesContextQuery as _EndpointServiceAvailabilityZonesContextQuery_ea2c3fa6,
-    ContextProvider as _ContextProvider_25ce5cb1,
-    FileAssetMetadataEntry as _FileAssetMetadataEntry_401d6b3e,
+    AwsCloudFormationStackProperties as _AwsCloudFormationStackProperties_cbabc075,
     ContainerImageAssetMetadataEntry as _ContainerImageAssetMetadataEntry_d177c3e3,
+    ContextProvider as _ContextProvider_25ce5cb1,
+    EndpointServiceAvailabilityZonesContextQuery as _EndpointServiceAvailabilityZonesContextQuery_ea2c3fa6,
+    FileAssetMetadataEntry as _FileAssetMetadataEntry_401d6b3e,
+    HostedZoneContextQuery as _HostedZoneContextQuery_42616509,
+    MetadataEntry as _MetadataEntry_1c069657,
+    MissingContext as _MissingContext_d8a115db,
+    NestedCloudAssemblyProperties as _NestedCloudAssemblyProperties_2d939e98,
+    RuntimeInfo as _RuntimeInfo_847d082a,
+    SSMParameterContextQuery as _SSMParameterContextQuery_f21616f8,
     Tag as _Tag_9bdb11cc,
+    TreeArtifactProperties as _TreeArtifactProperties_8af66c6c,
+    VpcContextQuery as _VpcContextQuery_65dc9cbf,
 )
 
 
@@ -187,17 +187,8 @@ class CloudArtifact(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> None:
         """
         :param assembly: -
@@ -231,17 +222,8 @@ class CloudArtifact(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> typing.Optional["CloudArtifact"]:
         """Returns a subclass of ``CloudArtifact`` based on the artifact type defined in the artifact manifest.
 
@@ -543,17 +525,8 @@ class CloudAssemblyBuilder(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> None:
         """Adds an artifact into the cloud assembly.
 
@@ -582,14 +555,7 @@ class CloudAssemblyBuilder(
         self,
         *,
         key: str,
-        props: typing.Union[
-            _AmiContextQuery_f862ae87,
-            _AvailabilityZonesContextQuery_9a5bac5f,
-            _HostedZoneContextQuery_42616509,
-            _SSMParameterContextQuery_f21616f8,
-            _VpcContextQuery_65dc9cbf,
-            _EndpointServiceAvailabilityZonesContextQuery_ea2c3fa6,
-        ],
+        props: typing.Union[_AmiContextQuery_f862ae87, _AvailabilityZonesContextQuery_9a5bac5f, _HostedZoneContextQuery_42616509, _SSMParameterContextQuery_f21616f8, _VpcContextQuery_65dc9cbf, _EndpointServiceAvailabilityZonesContextQuery_ea2c3fa6],
         provider: _ContextProvider_25ce5cb1,
     ) -> None:
         """Reports that some context is missing in order for this cloud assembly to be fully synthesized.
@@ -663,17 +629,8 @@ class CloudFormationStackArtifact(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> None:
         """
         :param assembly: -
@@ -695,19 +652,13 @@ class CloudFormationStackArtifact(
             properties=properties,
         )
 
-        jsii.create(
-            CloudFormationStackArtifact, self, [assembly, artifact_id, artifact]
-        )
+        jsii.create(CloudFormationStackArtifact, self, [assembly, artifact_id, artifact])
 
     @builtins.property
     @jsii.member(jsii_name="assets")
     def assets(
         self,
-    ) -> typing.List[
-        typing.Union[
-            _FileAssetMetadataEntry_401d6b3e, _ContainerImageAssetMetadataEntry_d177c3e3
-        ]
-    ]:
+    ) -> typing.List[typing.Union[_FileAssetMetadataEntry_401d6b3e, _ContainerImageAssetMetadataEntry_d177c3e3]]:
         """Any assets associated with this stack.
 
         stability
@@ -1078,6 +1029,10 @@ class EnvironmentPlaceholders(
     """
 
     def __init__(self) -> None:
+        """
+        stability
+        :stability: experimental
+        """
         jsii.create(EnvironmentPlaceholders, self, [])
 
     @jsii.member(jsii_name="replace")
@@ -1159,6 +1114,10 @@ class EnvironmentUtils(
     """
 
     def __init__(self) -> None:
+        """
+        stability
+        :stability: experimental
+        """
         jsii.create(EnvironmentUtils, self, [])
 
     @jsii.member(jsii_name="format")
@@ -1286,14 +1245,7 @@ class MetadataEntry(_MetadataEntry_1c069657):
         self,
         *,
         type: str,
-        data: typing.Optional[
-            typing.Union[
-                str,
-                _FileAssetMetadataEntry_401d6b3e,
-                _ContainerImageAssetMetadataEntry_d177c3e3,
-                typing.List[_Tag_9bdb11cc],
-            ]
-        ] = None,
+        data: typing.Optional[typing.Union[str, _FileAssetMetadataEntry_401d6b3e, _ContainerImageAssetMetadataEntry_d177c3e3, typing.List[_Tag_9bdb11cc]]] = None,
         trace: typing.Optional[typing.List[str]] = None,
     ) -> None:
         """Backwards compatibility for when ``MetadataEntry`` was defined here.
@@ -1334,14 +1286,7 @@ class MetadataEntry(_MetadataEntry_1c069657):
     @builtins.property
     def data(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            str,
-            _FileAssetMetadataEntry_401d6b3e,
-            _ContainerImageAssetMetadataEntry_d177c3e3,
-            typing.List[_Tag_9bdb11cc],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[str, _FileAssetMetadataEntry_401d6b3e, _ContainerImageAssetMetadataEntry_d177c3e3, typing.List[_Tag_9bdb11cc]]]:
         """The data.
 
         default
@@ -1386,14 +1331,7 @@ class MetadataEntryResult(_MetadataEntry_1c069657):
         self,
         *,
         type: str,
-        data: typing.Optional[
-            typing.Union[
-                str,
-                _FileAssetMetadataEntry_401d6b3e,
-                _ContainerImageAssetMetadataEntry_d177c3e3,
-                typing.List[_Tag_9bdb11cc],
-            ]
-        ] = None,
+        data: typing.Optional[typing.Union[str, _FileAssetMetadataEntry_401d6b3e, _ContainerImageAssetMetadataEntry_d177c3e3, typing.List[_Tag_9bdb11cc]]] = None,
         trace: typing.Optional[typing.List[str]] = None,
         path: str,
     ) -> None:
@@ -1427,14 +1365,7 @@ class MetadataEntryResult(_MetadataEntry_1c069657):
     @builtins.property
     def data(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            str,
-            _FileAssetMetadataEntry_401d6b3e,
-            _ContainerImageAssetMetadataEntry_d177c3e3,
-            typing.List[_Tag_9bdb11cc],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[str, _FileAssetMetadataEntry_401d6b3e, _ContainerImageAssetMetadataEntry_d177c3e3, typing.List[_Tag_9bdb11cc]]]:
         """The data.
 
         default
@@ -1575,17 +1506,8 @@ class NestedCloudAssemblyArtifact(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> None:
         """
         :param assembly: -
@@ -1705,7 +1627,11 @@ class RuntimeInfo(_RuntimeInfo_847d082a):
 )
 class SynthesisMessage:
     def __init__(
-        self, *, entry: _MetadataEntry_1c069657, id: str, level: "SynthesisMessageLevel"
+        self,
+        *,
+        entry: _MetadataEntry_1c069657,
+        id: str,
+        level: "SynthesisMessageLevel",
     ) -> None:
         """
         :param entry: 
@@ -1801,17 +1727,8 @@ class TreeCloudArtifact(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> None:
         """
         :param assembly: -
@@ -1913,25 +1830,19 @@ class VpcContextResponse:
         if isolated_subnet_names is not None:
             self._values["isolated_subnet_names"] = isolated_subnet_names
         if isolated_subnet_route_table_ids is not None:
-            self._values[
-                "isolated_subnet_route_table_ids"
-            ] = isolated_subnet_route_table_ids
+            self._values["isolated_subnet_route_table_ids"] = isolated_subnet_route_table_ids
         if private_subnet_ids is not None:
             self._values["private_subnet_ids"] = private_subnet_ids
         if private_subnet_names is not None:
             self._values["private_subnet_names"] = private_subnet_names
         if private_subnet_route_table_ids is not None:
-            self._values[
-                "private_subnet_route_table_ids"
-            ] = private_subnet_route_table_ids
+            self._values["private_subnet_route_table_ids"] = private_subnet_route_table_ids
         if public_subnet_ids is not None:
             self._values["public_subnet_ids"] = public_subnet_ids
         if public_subnet_names is not None:
             self._values["public_subnet_names"] = public_subnet_names
         if public_subnet_route_table_ids is not None:
-            self._values[
-                "public_subnet_route_table_ids"
-            ] = public_subnet_route_table_ids
+            self._values["public_subnet_route_table_ids"] = public_subnet_route_table_ids
         if subnet_groups is not None:
             self._values["subnet_groups"] = subnet_groups
         if vpc_cidr_block is not None:
@@ -2316,17 +2227,8 @@ class AssetManifestArtifact(
         type: _ArtifactType_9221e05d,
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                _AwsCloudFormationStackProperties_cbabc075,
-                _AssetManifestProperties_8c80271b,
-                _TreeArtifactProperties_8af66c6c,
-                _NestedCloudAssemblyProperties_2d939e98,
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]] = None,
+        properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]] = None,
     ) -> None:
         """
         :param assembly: -
